# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointChild(Model):
    """MonitoringPointChild.

    :param monitoring_point_id:
    :type monitoring_point_id: str
    :param monitoring_point_name:
    :type monitoring_point_name: str
    :param monitoring_point_abbreviation:
    :type monitoring_point_abbreviation: str
    :param monitoring_point_type: Possible values include: 'Custom',
     'Vibration', 'Pressure', 'OilQuality', 'GeneralInput', 'IndicatorBased',
     'GeneralAtoD'
    :type monitoring_point_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'monitoring_point_id': {'key': 'MonitoringPointId', 'type': 'str'},
        'monitoring_point_name': {'key': 'MonitoringPointName', 'type': 'str'},
        'monitoring_point_abbreviation': {'key': 'MonitoringPointAbbreviation', 'type': 'str'},
        'monitoring_point_type': {'key': 'MonitoringPointType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MonitoringPointChild, self).__init__(**kwargs)
        self.monitoring_point_id = kwargs.get('monitoring_point_id', None)
        self.monitoring_point_name = kwargs.get('monitoring_point_name', None)
        self.monitoring_point_abbreviation = kwargs.get('monitoring_point_abbreviation', None)
        self.monitoring_point_type = kwargs.get('monitoring_point_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertyResponse(Model):
    """PropertyResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param name: Required.
    :type name: str
    :param value_type: Required.
    :type value_type: str
    :param description:
    :type description: str
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'value_type': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'name': {'key': 'Name', 'type': 'str'},
        'value_type': {'key': 'ValueType', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
    }

    def __init__(self, *, id: int, name: str, value_type: str, description: str=None, **kwargs) -> None:
        super(PropertyResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.value_type = value_type
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PersonalAccessTokenCreateRequest(Model):
    """PersonalAccessTokenCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param description: Required.
    :type description: str
    """

    _validation = {
        'description': {'required': True},
    }

    _attribute_map = {
        'description': {'key': 'Description', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PersonalAccessTokenCreateRequest, self).__init__(**kwargs)
        self.description = kwargs.get('description', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagResponse(Model):
    """TagResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param active: Required.
    :type active: bool
    :param type: Required. Possible values include: 'General', 'Components',
     'Make', 'Model', 'Location', 'Orientation', 'Asset', 'AssetCode',
     'Picture'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param is_global:
    :type is_global: bool
    :param created: Required.
    :type created: datetime
    :param updated: Required.
    :type updated: datetime
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'active': {'required': True},
        'type': {'required': True},
        'created': {'required': True},
        'updated': {'required': True},
        'location': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'type': {'key': 'Type', 'type': 'str'},
        'is_global': {'key': 'IsGlobal', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, **kwargs):
        super(TagResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.active = kwargs.get('active', None)
        self.type = kwargs.get('type', None)
        self.is_global = kwargs.get('is_global', None)
        self.created = kwargs.get('created', None)
        self.updated = kwargs.get('updated', None)
        self.location = kwargs.get('location', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCreateRequest(Model):
    """AssetCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param parent_id: Required.
    :type parent_id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param supplier:
    :type supplier: str
    :param manufacturer:
    :type manufacturer: str
    :param model_name:
    :type model_name: str
    :param location_notes:
    :type location_notes: str
    :param notes:
    :type notes: str
    :param generic_input:
    :type generic_input: str
    :param is_operator_view: Required.
    :type is_operator_view: bool
    :param type_id:
    :type type_id: int
    :param category_id:
    :type category_id: int
    :param size_id:
    :type size_id: int
    :param criticality_id:
    :type criticality_id: int
    :param asset_cost:
    :type asset_cost: float
    :param date_installed:
    :type date_installed: datetime
    :param annual_run_time:
    :type annual_run_time: float
    :param lost_production_cost:
    :type lost_production_cost: float
    :param overhaul_cost:
    :type overhaul_cost: float
    :param power_consumption:
    :type power_consumption: float
    :param life_expectancy:
    :type life_expectancy: float
    :param unscheduled_downtime:
    :type unscheduled_downtime: float
    :param running_speed_harmonic:
    :type running_speed_harmonic: float
    """

    _validation = {
        'parent_id': {'required': True},
        'name': {'required': True, 'max_length': 100},
        'abbreviation': {'max_length': 5},
        'supplier': {'max_length': 128},
        'manufacturer': {'max_length': 128},
        'model_name': {'max_length': 128},
        'location_notes': {'max_length': 256},
        'notes': {'max_length': 2000},
        'generic_input': {'max_length': 2000},
        'is_operator_view': {'required': True},
    }

    _attribute_map = {
        'parent_id': {'key': 'ParentId', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'supplier': {'key': 'Supplier', 'type': 'str'},
        'manufacturer': {'key': 'Manufacturer', 'type': 'str'},
        'model_name': {'key': 'ModelName', 'type': 'str'},
        'location_notes': {'key': 'LocationNotes', 'type': 'str'},
        'notes': {'key': 'Notes', 'type': 'str'},
        'generic_input': {'key': 'GenericInput', 'type': 'str'},
        'is_operator_view': {'key': 'IsOperatorView', 'type': 'bool'},
        'type_id': {'key': 'TypeId', 'type': 'int'},
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'size_id': {'key': 'SizeId', 'type': 'int'},
        'criticality_id': {'key': 'CriticalityId', 'type': 'int'},
        'asset_cost': {'key': 'AssetCost', 'type': 'float'},
        'date_installed': {'key': 'DateInstalled', 'type': 'iso-8601'},
        'annual_run_time': {'key': 'AnnualRunTime', 'type': 'float'},
        'lost_production_cost': {'key': 'LostProductionCost', 'type': 'float'},
        'overhaul_cost': {'key': 'OverhaulCost', 'type': 'float'},
        'power_consumption': {'key': 'PowerConsumption', 'type': 'float'},
        'life_expectancy': {'key': 'LifeExpectancy', 'type': 'float'},
        'unscheduled_downtime': {'key': 'UnscheduledDowntime', 'type': 'float'},
        'running_speed_harmonic': {'key': 'RunningSpeedHarmonic', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(AssetCreateRequest, self).__init__(**kwargs)
        self.parent_id = kwargs.get('parent_id', None)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.supplier = kwargs.get('supplier', None)
        self.manufacturer = kwargs.get('manufacturer', None)
        self.model_name = kwargs.get('model_name', None)
        self.location_notes = kwargs.get('location_notes', None)
        self.notes = kwargs.get('notes', None)
        self.generic_input = kwargs.get('generic_input', None)
        self.is_operator_view = kwargs.get('is_operator_view', None)
        self.type_id = kwargs.get('type_id', None)
        self.category_id = kwargs.get('category_id', None)
        self.size_id = kwargs.get('size_id', None)
        self.criticality_id = kwargs.get('criticality_id', None)
        self.asset_cost = kwargs.get('asset_cost', None)
        self.date_installed = kwargs.get('date_installed', None)
        self.annual_run_time = kwargs.get('annual_run_time', None)
        self.lost_production_cost = kwargs.get('lost_production_cost', None)
        self.overhaul_cost = kwargs.get('overhaul_cost', None)
        self.power_consumption = kwargs.get('power_consumption', None)
        self.life_expectancy = kwargs.get('life_expectancy', None)
        self.unscheduled_downtime = kwargs.get('unscheduled_downtime', None)
        self.running_speed_harmonic = kwargs.get('running_speed_harmonic', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilesError(Model):
    """FilesError.

    :param file_id:
    :type file_id: str
    :param display_name:
    :type display_name: str
    :param message:
    :type message: str
    """

    _attribute_map = {
        'file_id': {'key': 'FileId', 'type': 'str'},
        'display_name': {'key': 'DisplayName', 'type': 'str'},
        'message': {'key': 'Message', 'type': 'str'},
    }

    def __init__(self, *, file_id: str=None, display_name: str=None, message: str=None, **kwargs) -> None:
        super(FilesError, self).__init__(**kwargs)
        self.file_id = file_id
        self.display_name = display_name
        self.message = message



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DescendantChild(Model):
    """DescendantChild.

    :param child_id:
    :type child_id: str
    :param child_name:
    :type child_name: str
    :param child_abbreviation:
    :type child_abbreviation: str
    :param child_type: Possible values include: 'Asset', 'MonitoringPoint',
     'IndicatorGroup', 'Group', 'AnalyticModel'
    :type child_type: str or ~smartdiagnostics_sdk.models.enum
    :param child_sort_order:
    :type child_sort_order: int
    :param child_has_children:
    :type child_has_children: bool
    :param child_alarm_severity_level:
    :type child_alarm_severity_level: int
    :param child_is_paused:
    :type child_is_paused: bool
    :param child_is_snoozed:
    :type child_is_snoozed: bool
    """

    _attribute_map = {
        'child_id': {'key': 'ChildId', 'type': 'str'},
        'child_name': {'key': 'ChildName', 'type': 'str'},
        'child_abbreviation': {'key': 'ChildAbbreviation', 'type': 'str'},
        'child_type': {'key': 'ChildType', 'type': 'str'},
        'child_sort_order': {'key': 'ChildSortOrder', 'type': 'int'},
        'child_has_children': {'key': 'ChildHasChildren', 'type': 'bool'},
        'child_alarm_severity_level': {'key': 'ChildAlarmSeverityLevel', 'type': 'int'},
        'child_is_paused': {'key': 'ChildIsPaused', 'type': 'bool'},
        'child_is_snoozed': {'key': 'ChildIsSnoozed', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DescendantChild, self).__init__(**kwargs)
        self.child_id = kwargs.get('child_id', None)
        self.child_name = kwargs.get('child_name', None)
        self.child_abbreviation = kwargs.get('child_abbreviation', None)
        self.child_type = kwargs.get('child_type', None)
        self.child_sort_order = kwargs.get('child_sort_order', None)
        self.child_has_children = kwargs.get('child_has_children', None)
        self.child_alarm_severity_level = kwargs.get('child_alarm_severity_level', None)
        self.child_is_paused = kwargs.get('child_is_paused', None)
        self.child_is_snoozed = kwargs.get('child_is_snoozed', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareStatusChild(Model):
    """HardwareStatusChild.

    :param location_id:
    :type location_id: str
    :param location_name:
    :type location_name: str
    :param location_abbreviation:
    :type location_abbreviation: str
    :param hardware_count:
    :type hardware_count: int
    :param unassigned_count:
    :type unassigned_count: int
    :param online_count:
    :type online_count: int
    :param offline_count:
    :type offline_count: int
    """

    _attribute_map = {
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'location_abbreviation': {'key': 'LocationAbbreviation', 'type': 'str'},
        'hardware_count': {'key': 'HardwareCount', 'type': 'int'},
        'unassigned_count': {'key': 'UnassignedCount', 'type': 'int'},
        'online_count': {'key': 'OnlineCount', 'type': 'int'},
        'offline_count': {'key': 'OfflineCount', 'type': 'int'},
    }

    def __init__(self, *, location_id: str=None, location_name: str=None, location_abbreviation: str=None, hardware_count: int=None, unassigned_count: int=None, online_count: int=None, offline_count: int=None, **kwargs) -> None:
        super(HardwareStatusChild, self).__init__(**kwargs)
        self.location_id = location_id
        self.location_name = location_name
        self.location_abbreviation = location_abbreviation
        self.hardware_count = hardware_count
        self.unassigned_count = unassigned_count
        self.online_count = online_count
        self.offline_count = offline_count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupMoveRequest(Model):
    """GroupMoveRequest.

    All required parameters must be populated in order to send to Azure.

    :param sort_order: Required.
    :type sort_order: int
    :param parent_id: Required.
    :type parent_id: str
    """

    _validation = {
        'sort_order': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'parent_id': {'required': True},
    }

    _attribute_map = {
        'sort_order': {'key': 'SortOrder', 'type': 'int'},
        'parent_id': {'key': 'ParentId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GroupMoveRequest, self).__init__(**kwargs)
        self.sort_order = kwargs.get('sort_order', None)
        self.parent_id = kwargs.get('parent_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemOverviewResponse(Model):
    """SystemOverviewResponse.

    All required parameters must be populated in order to send to Azure.

    :param is_snoozed: Required.
    :type is_snoozed: bool
    :param description:
    :type description: str
    :param is_collector_dependent_system: Required.
    :type is_collector_dependent_system: bool
    :param is_favorited: Required.
    :type is_favorited: bool
    :param is_visible: Required.
    :type is_visible: bool
    :param asset_count: Required.
    :type asset_count: int
    :param asset_status_count:
    :type asset_status_count:
     ~smartdiagnostics_sdk.models.AssetsStatusCountChild
    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param active: Required.
    :type active: bool
    :param is_paused: Required.
    :type is_paused: bool
    :param created: Required.
    :type created: datetime
    :param corporation: Required.
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _validation = {
        'is_snoozed': {'required': True},
        'is_collector_dependent_system': {'required': True},
        'is_favorited': {'required': True},
        'is_visible': {'required': True},
        'asset_count': {'required': True},
        'id': {'required': True},
        'name': {'required': True},
        'active': {'required': True},
        'is_paused': {'required': True},
        'created': {'required': True},
        'corporation': {'required': True},
        'location': {'required': True},
    }

    _attribute_map = {
        'is_snoozed': {'key': 'IsSnoozed', 'type': 'bool'},
        'description': {'key': 'Description', 'type': 'str'},
        'is_collector_dependent_system': {'key': 'IsCollectorDependentSystem', 'type': 'bool'},
        'is_favorited': {'key': 'IsFavorited', 'type': 'bool'},
        'is_visible': {'key': 'IsVisible', 'type': 'bool'},
        'asset_count': {'key': 'AssetCount', 'type': 'int'},
        'asset_status_count': {'key': 'AssetStatusCount', 'type': 'AssetsStatusCountChild'},
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, *, is_snoozed: bool, is_collector_dependent_system: bool, is_favorited: bool, is_visible: bool, asset_count: int, id: str, name: str, active: bool, is_paused: bool, created, corporation, location, description: str=None, asset_status_count=None, abbreviation: str=None, **kwargs) -> None:
        super(SystemOverviewResponse, self).__init__(**kwargs)
        self.is_snoozed = is_snoozed
        self.description = description
        self.is_collector_dependent_system = is_collector_dependent_system
        self.is_favorited = is_favorited
        self.is_visible = is_visible
        self.asset_count = asset_count
        self.asset_status_count = asset_status_count
        self.id = id
        self.name = name
        self.abbreviation = abbreviation
        self.active = active
        self.is_paused = is_paused
        self.created = created
        self.corporation = corporation
        self.location = location



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingChild(Model):
    """NodeSettingChild.

    :param node_setting_name:
    :type node_setting_name: str
    :param node_setting_current_value:
    :type node_setting_current_value: str
    :param node_setting_pending_value:
    :type node_setting_pending_value: str
    """

    _attribute_map = {
        'node_setting_name': {'key': 'NodeSettingName', 'type': 'str'},
        'node_setting_current_value': {'key': 'NodeSettingCurrentValue', 'type': 'str'},
        'node_setting_pending_value': {'key': 'NodeSettingPendingValue', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(NodeSettingChild, self).__init__(**kwargs)
        self.node_setting_name = kwargs.get('node_setting_name', None)
        self.node_setting_current_value = kwargs.get('node_setting_current_value', None)
        self.node_setting_pending_value = kwargs.get('node_setting_pending_value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TargetedSoftwareReleaseChild(Model):
    """TargetedSoftwareReleaseChild.

    :param targeted_software_release_id:
    :type targeted_software_release_id: int
    :param targeted_software_release_name:
    :type targeted_software_release_name: str
    """

    _attribute_map = {
        'targeted_software_release_id': {'key': 'TargetedSoftwareReleaseId', 'type': 'int'},
        'targeted_software_release_name': {'key': 'TargetedSoftwareReleaseName', 'type': 'str'},
    }

    def __init__(self, *, targeted_software_release_id: int=None, targeted_software_release_name: str=None, **kwargs) -> None:
        super(TargetedSoftwareReleaseChild, self).__init__(**kwargs)
        self.targeted_software_release_id = targeted_software_release_id
        self.targeted_software_release_name = targeted_software_release_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardWidgetChild(Model):
    """DashboardWidgetChild.

    All required parameters must be populated in order to send to Azure.

    :param dashboard_widget_id: Required.
    :type dashboard_widget_id: str
    :param dashboard_widget_name: Required.
    :type dashboard_widget_name: str
    :param dashboard_widget_refresh_interval:
    :type dashboard_widget_refresh_interval: int
    :param dashboard_widget_layout:
    :type dashboard_widget_layout: ~smartdiagnostics_sdk.models.LayoutChild
    :param widget:
    :type widget: ~smartdiagnostics_sdk.models.WidgetChild
    """

    _validation = {
        'dashboard_widget_id': {'required': True},
        'dashboard_widget_name': {'required': True},
    }

    _attribute_map = {
        'dashboard_widget_id': {'key': 'DashboardWidgetId', 'type': 'str'},
        'dashboard_widget_name': {'key': 'DashboardWidgetName', 'type': 'str'},
        'dashboard_widget_refresh_interval': {'key': 'DashboardWidgetRefreshInterval', 'type': 'int'},
        'dashboard_widget_layout': {'key': 'DashboardWidgetLayout', 'type': 'LayoutChild'},
        'widget': {'key': 'Widget', 'type': 'WidgetChild'},
    }

    def __init__(self, *, dashboard_widget_id: str, dashboard_widget_name: str, dashboard_widget_refresh_interval: int=None, dashboard_widget_layout=None, widget=None, **kwargs) -> None:
        super(DashboardWidgetChild, self).__init__(**kwargs)
        self.dashboard_widget_id = dashboard_widget_id
        self.dashboard_widget_name = dashboard_widget_name
        self.dashboard_widget_refresh_interval = dashboard_widget_refresh_interval
        self.dashboard_widget_layout = dashboard_widget_layout
        self.widget = widget



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProblemDetails(Model):
    """ProblemDetails.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param type:
    :type type: str
    :param title:
    :type title: str
    :param status:
    :type status: int
    :param detail:
    :type detail: str
    :param instance:
    :type instance: str
    :ivar extensions:
    :vartype extensions: dict[str, object]
    """

    _validation = {
        'extensions': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'Type', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
        'status': {'key': 'Status', 'type': 'int'},
        'detail': {'key': 'Detail', 'type': 'str'},
        'instance': {'key': 'Instance', 'type': 'str'},
        'extensions': {'key': 'Extensions', 'type': '{object}'},
    }

    def __init__(self, **kwargs):
        super(ProblemDetails, self).__init__(**kwargs)
        self.type = kwargs.get('type', None)
        self.title = kwargs.get('title', None)
        self.status = kwargs.get('status', None)
        self.detail = kwargs.get('detail', None)
        self.instance = kwargs.get('instance', None)
        self.extensions = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationChild(Model):
    """LocationChild.

    All required parameters must be populated in order to send to Azure.

    :param location_id: Required.
    :type location_id: str
    :param location_name: Required.
    :type location_name: str
    :param location_abbreviation:
    :type location_abbreviation: str
    """

    _validation = {
        'location_id': {'required': True},
        'location_name': {'required': True},
    }

    _attribute_map = {
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'location_abbreviation': {'key': 'LocationAbbreviation', 'type': 'str'},
    }

    def __init__(self, *, location_id: str, location_name: str, location_abbreviation: str=None, **kwargs) -> None:
        super(LocationChild, self).__init__(**kwargs)
        self.location_id = location_id
        self.location_name = location_name
        self.location_abbreviation = location_abbreviation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelChild(Model):
    """AnalyticsModelChild.

    All required parameters must be populated in order to send to Azure.

    :param analytics_model_id: Required.
    :type analytics_model_id: int
    :param analytics_model_name: Required.
    :type analytics_model_name: str
    :param analytics_model_version: Required.
    :type analytics_model_version: str
    """

    _validation = {
        'analytics_model_id': {'required': True},
        'analytics_model_name': {'required': True},
        'analytics_model_version': {'required': True},
    }

    _attribute_map = {
        'analytics_model_id': {'key': 'AnalyticsModelId', 'type': 'int'},
        'analytics_model_name': {'key': 'AnalyticsModelName', 'type': 'str'},
        'analytics_model_version': {'key': 'AnalyticsModelVersion', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelChild, self).__init__(**kwargs)
        self.analytics_model_id = kwargs.get('analytics_model_id', None)
        self.analytics_model_name = kwargs.get('analytics_model_name', None)
        self.analytics_model_version = kwargs.get('analytics_model_version', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetDrumRollChild(Model):
    """AssetDrumRollChild.

    :param drum_roll_diameter:
    :type drum_roll_diameter: int
    :param drum_roll_diameter_unit:
    :type drum_roll_diameter_unit: str
    """

    _attribute_map = {
        'drum_roll_diameter': {'key': 'DrumRollDiameter', 'type': 'int'},
        'drum_roll_diameter_unit': {'key': 'DrumRollDiameterUnit', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AssetDrumRollChild, self).__init__(**kwargs)
        self.drum_roll_diameter = kwargs.get('drum_roll_diameter', None)
        self.drum_roll_diameter_unit = kwargs.get('drum_roll_diameter_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareEventModelV3(Model):
    """HardwareEventModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The Id of the hardware event
    :type id: long
    :param hardware_type: The type of hardware that caused the event
    :type hardware_type: str
    :param event_type: The event type that happened
    :type event_type: str
    :param time_entered: Time hardware enter the event type
    :type time_entered: datetime
    :param time_notified: Time notifications where sent out
    :type time_notified: datetime
    :param time_exited: The time the hardware exited the event
    :type time_exited: datetime
    :param time_acked: Time a user acknowledged the event
    :type time_acked: datetime
    :param created: Time the log entry was created
    :type created: datetime
    :param last_modified: Last time the event entry was modified
    :type last_modified: datetime
    :param node:
    :type node: ~smartdiagnostics_sdk.models.HardwareModelV3
    :param collector:
    :type collector: ~smartdiagnostics_sdk.models.HardwareModelV3
    :param repeater:
    :type repeater: ~smartdiagnostics_sdk.models.HardwareModelV3
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'hardware_type': {'key': 'HardwareType', 'type': 'str'},
        'event_type': {'key': 'EventType', 'type': 'str'},
        'time_entered': {'key': 'TimeEntered', 'type': 'iso-8601'},
        'time_notified': {'key': 'TimeNotified', 'type': 'iso-8601'},
        'time_exited': {'key': 'TimeExited', 'type': 'iso-8601'},
        'time_acked': {'key': 'TimeAcked', 'type': 'iso-8601'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'last_modified': {'key': 'LastModified', 'type': 'iso-8601'},
        'node': {'key': 'Node', 'type': 'HardwareModelV3'},
        'collector': {'key': 'Collector', 'type': 'HardwareModelV3'},
        'repeater': {'key': 'Repeater', 'type': 'HardwareModelV3'},
    }

    def __init__(self, *, id: int, hardware_type: str=None, event_type: str=None, time_entered=None, time_notified=None, time_exited=None, time_acked=None, created=None, last_modified=None, node=None, collector=None, repeater=None, **kwargs) -> None:
        super(HardwareEventModelV3, self).__init__(**kwargs)
        self.id = id
        self.hardware_type = hardware_type
        self.event_type = event_type
        self.time_entered = time_entered
        self.time_notified = time_notified
        self.time_exited = time_exited
        self.time_acked = time_acked
        self.created = created
        self.last_modified = last_modified
        self.node = node
        self.collector = collector
        self.repeater = repeater



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAnalyticsModelUpdateRequest(Model):
    """GroupAnalyticsModelUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param properties: Required.
    :type properties: list[~smartdiagnostics_sdk.models.SetPropertyChild]
    """

    _validation = {
        'properties': {'required': True},
    }

    _attribute_map = {
        'properties': {'key': 'Properties', 'type': '[SetPropertyChild]'},
    }

    def __init__(self, *, properties, **kwargs) -> None:
        super(GroupAnalyticsModelUpdateRequest, self).__init__(**kwargs)
        self.properties = properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PersonalAccessTokenResponse(Model):
    """PersonalAccessTokenResponse.

    :param id:
    :type id: str
    :param description:
    :type description: str
    :param created:
    :type created: datetime
    :param updated:
    :type updated: datetime
    :param last_used:
    :type last_used: datetime
    :param active:
    :type active: bool
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'last_used': {'key': 'LastUsed', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
    }

    def __init__(self, *, id: str=None, description: str=None, created=None, updated=None, last_used=None, active: bool=None, **kwargs) -> None:
        super(PersonalAccessTokenResponse, self).__init__(**kwargs)
        self.id = id
        self.description = description
        self.created = created
        self.updated = updated
        self.last_used = last_used
        self.active = active



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DocumentChild(Model):
    """DocumentChild.

    :param document_url:
    :type document_url: str
    :param document_name:
    :type document_name: str
    """

    _attribute_map = {
        'document_url': {'key': 'DocumentUrl', 'type': 'str'},
        'document_name': {'key': 'DocumentName', 'type': 'str'},
    }

    def __init__(self, *, document_url: str=None, document_name: str=None, **kwargs) -> None:
        super(DocumentChild, self).__init__(**kwargs)
        self.document_url = document_url
        self.document_name = document_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PrimaryCorporationChild(Model):
    """PrimaryCorporationChild.

    All required parameters must be populated in order to send to Azure.

    :param corporation_id: Required.
    :type corporation_id: str
    :param corporation_name: Required.
    :type corporation_name: str
    :param corporation_abbreviation:
    :type corporation_abbreviation: str
    """

    _validation = {
        'corporation_id': {'required': True},
        'corporation_name': {'required': True},
    }

    _attribute_map = {
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'corporation_name': {'key': 'CorporationName', 'type': 'str'},
        'corporation_abbreviation': {'key': 'CorporationAbbreviation', 'type': 'str'},
    }

    def __init__(self, *, corporation_id: str, corporation_name: str, corporation_abbreviation: str=None, **kwargs) -> None:
        super(PrimaryCorporationChild, self).__init__(**kwargs)
        self.corporation_id = corporation_id
        self.corporation_name = corporation_name
        self.corporation_abbreviation = corporation_abbreviation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseStationResponse(Model):
    """BaseStationResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: long
    :param serial_number: Required.
    :type serial_number: str
    :param nickname:
    :type nickname: str
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param last_status_update:
    :type last_status_update: datetime
    :param push_to_stage:
    :type push_to_stage: bool
    :param release_ring:
    :type release_ring: ~smartdiagnostics_sdk.models.ReleaseRingChild
    :param targeted_software_release:
    :type targeted_software_release:
     ~smartdiagnostics_sdk.models.TargetedSoftwareReleaseChild
    :param current_software_release:
    :type current_software_release:
     ~smartdiagnostics_sdk.models.CurrentSoftwareReleaseChild
    :param hardware_revision:
    :type hardware_revision:
     ~smartdiagnostics_sdk.models.HardwareRevisionChild
    :param receiver:
    :type receiver: ~smartdiagnostics_sdk.models.ReceiverChild
    :param last_data_update:
    :type last_data_update: datetime
    :param is_online:
    :type is_online: bool
    """

    _validation = {
        'id': {'required': True},
        'serial_number': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'nickname': {'key': 'Nickname', 'type': 'str'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'last_status_update': {'key': 'LastStatusUpdate', 'type': 'iso-8601'},
        'push_to_stage': {'key': 'PushToStage', 'type': 'bool'},
        'release_ring': {'key': 'ReleaseRing', 'type': 'ReleaseRingChild'},
        'targeted_software_release': {'key': 'TargetedSoftwareRelease', 'type': 'TargetedSoftwareReleaseChild'},
        'current_software_release': {'key': 'CurrentSoftwareRelease', 'type': 'CurrentSoftwareReleaseChild'},
        'hardware_revision': {'key': 'HardwareRevision', 'type': 'HardwareRevisionChild'},
        'receiver': {'key': 'Receiver', 'type': 'ReceiverChild'},
        'last_data_update': {'key': 'LastDataUpdate', 'type': 'iso-8601'},
        'is_online': {'key': 'IsOnline', 'type': 'bool'},
    }

    def __init__(self, *, id: int, serial_number: str, nickname: str=None, location=None, corporation=None, last_status_update=None, push_to_stage: bool=None, release_ring=None, targeted_software_release=None, current_software_release=None, hardware_revision=None, receiver=None, last_data_update=None, is_online: bool=None, **kwargs) -> None:
        super(BaseStationResponse, self).__init__(**kwargs)
        self.id = id
        self.serial_number = serial_number
        self.nickname = nickname
        self.location = location
        self.corporation = corporation
        self.last_status_update = last_status_update
        self.push_to_stage = push_to_stage
        self.release_ring = release_ring
        self.targeted_software_release = targeted_software_release
        self.current_software_release = current_software_release
        self.hardware_revision = hardware_revision
        self.receiver = receiver
        self.last_data_update = last_data_update
        self.is_online = is_online



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RoiResponse(Model):
    """RoiResponse.

    :param savings:
    :type savings: float
    :param roi_percentage:
    :type roi_percentage: float
    :param roi_ratio:
    :type roi_ratio: float
    """

    _attribute_map = {
        'savings': {'key': 'Savings', 'type': 'float'},
        'roi_percentage': {'key': 'RoiPercentage', 'type': 'float'},
        'roi_ratio': {'key': 'RoiRatio', 'type': 'float'},
    }

    def __init__(self, *, savings: float=None, roi_percentage: float=None, roi_ratio: float=None, **kwargs) -> None:
        super(RoiResponse, self).__init__(**kwargs)
        self.savings = savings
        self.roi_percentage = roi_percentage
        self.roi_ratio = roi_ratio



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupChild(Model):
    """GroupChild.

    All required parameters must be populated in order to send to Azure.

    :param group_id: Required.
    :type group_id: str
    :param group_name: Required.
    :type group_name: str
    :param group_abbreviation:
    :type group_abbreviation: str
    :param group_type: Required. Possible values include: 'Asset',
     'MonitoringPoint', 'IndicatorGroup', 'Group', 'AnalyticModel'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'group_id': {'required': True},
        'group_name': {'required': True},
        'group_type': {'required': True},
    }

    _attribute_map = {
        'group_id': {'key': 'GroupId', 'type': 'str'},
        'group_name': {'key': 'GroupName', 'type': 'str'},
        'group_abbreviation': {'key': 'GroupAbbreviation', 'type': 'str'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GroupChild, self).__init__(**kwargs)
        self.group_id = kwargs.get('group_id', None)
        self.group_name = kwargs.get('group_name', None)
        self.group_abbreviation = kwargs.get('group_abbreviation', None)
        self.group_type = kwargs.get('group_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OverviewHierarchyChild(Model):
    """OverviewHierarchyChild.

    :param hierarchy_id:
    :type hierarchy_id: str
    :param hierarchy_name:
    :type hierarchy_name: str
    :param hierarchy_abbreviation:
    :type hierarchy_abbreviation: str
    :param hierarchy_type:
    :type hierarchy_type: str
    """

    _attribute_map = {
        'hierarchy_id': {'key': 'HierarchyId', 'type': 'str'},
        'hierarchy_name': {'key': 'HierarchyName', 'type': 'str'},
        'hierarchy_abbreviation': {'key': 'HierarchyAbbreviation', 'type': 'str'},
        'hierarchy_type': {'key': 'HierarchyType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(OverviewHierarchyChild, self).__init__(**kwargs)
        self.hierarchy_id = kwargs.get('hierarchy_id', None)
        self.hierarchy_name = kwargs.get('hierarchy_name', None)
        self.hierarchy_abbreviation = kwargs.get('hierarchy_abbreviation', None)
        self.hierarchy_type = kwargs.get('hierarchy_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveFilesResponse(Model):
    """MoveFilesResponse.

    :param destination_folder_id:
    :type destination_folder_id: str
    :param success_count:
    :type success_count: int
    :param error_count:
    :type error_count: int
    :param errors:
    :type errors: list[~smartdiagnostics_sdk.models.FilesError]
    """

    _attribute_map = {
        'destination_folder_id': {'key': 'DestinationFolderId', 'type': 'str'},
        'success_count': {'key': 'SuccessCount', 'type': 'int'},
        'error_count': {'key': 'ErrorCount', 'type': 'int'},
        'errors': {'key': 'Errors', 'type': '[FilesError]'},
    }

    def __init__(self, **kwargs):
        super(MoveFilesResponse, self).__init__(**kwargs)
        self.destination_folder_id = kwargs.get('destination_folder_id', None)
        self.success_count = kwargs.get('success_count', None)
        self.error_count = kwargs.get('error_count', None)
        self.errors = kwargs.get('errors', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagCreateRequest(Model):
    """TagCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param type: Required. Possible values include: 'General', 'Components',
     'Make', 'Model', 'Location', 'Orientation', 'Asset', 'AssetCode',
     'Picture'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param location_id: Required.
    :type location_id: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'type': {'required': True},
        'location_id': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'type': {'key': 'Type', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
    }

    def __init__(self, *, name: str, type, location_id: str, **kwargs) -> None:
        super(TagCreateRequest, self).__init__(**kwargs)
        self.name = name
        self.type = type
        self.location_id = location_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RepeaterModelV3(Model):
    """RepeaterModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id:
    :type id: long
    :param serial_number: Required.
    :type serial_number: str
    :param radio_mac_address:
    :type radio_mac_address: str
    :param location_id:
    :type location_id: str
    :param location_name:
    :type location_name: str
    :param corporation_id:
    :type corporation_id: str
    :param corporation_name:
    :type corporation_name: str
    :param last_status_update:
    :type last_status_update: datetime
    :param active:
    :type active: bool
    :param type: Possible values include: 'Unknown', 'BaseStation', 'Repeater'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'serial_number': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'radio_mac_address': {'key': 'RadioMacAddress', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'corporation_name': {'key': 'CorporationName', 'type': 'str'},
        'last_status_update': {'key': 'LastStatusUpdate', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
        'type': {'key': 'Type', 'type': 'str'},
    }

    def __init__(self, *, serial_number: str, id: int=None, radio_mac_address: str=None, location_id: str=None, location_name: str=None, corporation_id: str=None, corporation_name: str=None, last_status_update=None, active: bool=None, type=None, **kwargs) -> None:
        super(RepeaterModelV3, self).__init__(**kwargs)
        self.id = id
        self.serial_number = serial_number
        self.radio_mac_address = radio_mac_address
        self.location_id = location_id
        self.location_name = location_name
        self.corporation_id = corporation_id
        self.corporation_name = corporation_name
        self.last_status_update = last_status_update
        self.active = active
        self.type = type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAnalyticsModelResponse(Model):
    """GroupAnalyticsModelResponse.

    All required parameters must be populated in order to send to Azure.

    :param group: Required.
    :type group: ~smartdiagnostics_sdk.models.GroupChild
    :param id: Required.
    :type id: int
    :param name: Required.
    :type name: str
    :param version: Required.
    :type version: str
    :param type: Possible values include: 'SMARTIndicator', 'Classifier'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param created:
    :type created: datetime
    :param group_type: Possible values include: 'Asset', 'MonitoringPoint',
     'IndicatorGroup', 'Group', 'AnalyticModel'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    :param is_global:
    :type is_global: bool
    :param is_deprecated:
    :type is_deprecated: bool
    :param indicators:
    :type indicators:
     list[~smartdiagnostics_sdk.models.AnalyticsModelIndicatorChild]
    :param properties:
    :type properties: list[~smartdiagnostics_sdk.models.PropertyChild]
    :param related_models:
    :type related_models:
     list[~smartdiagnostics_sdk.models.AnalyticsModelRelatedModelChild]
    :param created_by:
    :type created_by: ~smartdiagnostics_sdk.models.UserChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param triggers:
    :type triggers: list[~smartdiagnostics_sdk.models.TriggerChild]
    """

    _validation = {
        'group': {'required': True},
        'id': {'required': True},
        'name': {'required': True},
        'version': {'required': True},
    }

    _attribute_map = {
        'group': {'key': 'Group', 'type': 'GroupChild'},
        'id': {'key': 'Id', 'type': 'int'},
        'name': {'key': 'Name', 'type': 'str'},
        'version': {'key': 'Version', 'type': 'str'},
        'type': {'key': 'Type', 'type': 'str'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
        'is_global': {'key': 'IsGlobal', 'type': 'bool'},
        'is_deprecated': {'key': 'IsDeprecated', 'type': 'bool'},
        'indicators': {'key': 'Indicators', 'type': '[AnalyticsModelIndicatorChild]'},
        'properties': {'key': 'Properties', 'type': '[PropertyChild]'},
        'related_models': {'key': 'RelatedModels', 'type': '[AnalyticsModelRelatedModelChild]'},
        'created_by': {'key': 'CreatedBy', 'type': 'UserChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'triggers': {'key': 'Triggers', 'type': '[TriggerChild]'},
    }

    def __init__(self, **kwargs):
        super(GroupAnalyticsModelResponse, self).__init__(**kwargs)
        self.group = kwargs.get('group', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.version = kwargs.get('version', None)
        self.type = kwargs.get('type', None)
        self.created = kwargs.get('created', None)
        self.group_type = kwargs.get('group_type', None)
        self.is_global = kwargs.get('is_global', None)
        self.is_deprecated = kwargs.get('is_deprecated', None)
        self.indicators = kwargs.get('indicators', None)
        self.properties = kwargs.get('properties', None)
        self.related_models = kwargs.get('related_models', None)
        self.created_by = kwargs.get('created_by', None)
        self.corporation = kwargs.get('corporation', None)
        self.location = kwargs.get('location', None)
        self.triggers = kwargs.get('triggers', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardCreateRequest(Model):
    """DashboardCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name:
    :type name: str
    :param description:
    :type description: str
    :param template_id: Required.
    :type template_id: int
    :param corporation_id: Required.
    :type corporation_id: str
    :param location_id:
    :type location_id: str
    :param time_range: Possible values include: 'EightHours', 'OneDay',
     'OneWeek', 'OneMonth', 'OneYear'
    :type time_range: str or ~smartdiagnostics_sdk.models.enum
    :param power_bi_report_url:
    :type power_bi_report_url: str
    """

    _validation = {
        'name': {'max_length': 128, 'min_length': 0},
        'description': {'max_length': 1000, 'min_length': 0},
        'template_id': {'required': True},
        'corporation_id': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'template_id': {'key': 'TemplateId', 'type': 'int'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'time_range': {'key': 'TimeRange', 'type': 'str'},
        'power_bi_report_url': {'key': 'PowerBiReportUrl', 'type': 'str'},
    }

    def __init__(self, *, template_id: int, corporation_id: str, name: str=None, description: str=None, location_id: str=None, time_range=None, power_bi_report_url: str=None, **kwargs) -> None:
        super(DashboardCreateRequest, self).__init__(**kwargs)
        self.name = name
        self.description = description
        self.template_id = template_id
        self.corporation_id = corporation_id
        self.location_id = location_id
        self.time_range = time_range
        self.power_bi_report_url = power_bi_report_url



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttachmentModelV3(Model):
    """AttachmentModelV3.

    All required parameters must be populated in order to send to Azure.

    :param type: Possible values include: 'Corporation', 'Account', 'Group',
     'Other', 'Indicator'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param id: Required.
    :type id: str
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'type': {'key': 'Type', 'type': 'str'},
        'id': {'key': 'Id', 'type': 'str'},
    }

    def __init__(self, *, id: str, type=None, **kwargs) -> None:
        super(AttachmentModelV3, self).__init__(**kwargs)
        self.type = type
        self.id = id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetTypeResponse(Model):
    """AssetTypeResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param name: Required.
    :type name: str
    :param code: Required.
    :type code: str
    :param categories: Required.
    :type categories:
     list[~smartdiagnostics_sdk.models.AssetCategoryWithSizeChild]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'code': {'required': True},
        'categories': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'name': {'key': 'Name', 'type': 'str'},
        'code': {'key': 'Code', 'type': 'str'},
        'categories': {'key': 'Categories', 'type': '[AssetCategoryWithSizeChild]'},
    }

    def __init__(self, *, id: int, name: str, code: str, categories, **kwargs) -> None:
        super(AssetTypeResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.code = code
        self.categories = categories



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityCodeChild(Model):
    """ActivityCodeChild.

    :param activity_code_id:
    :type activity_code_id: str
    :param activity_code_name:
    :type activity_code_name: str
    """

    _attribute_map = {
        'activity_code_id': {'key': 'ActivityCodeId', 'type': 'str'},
        'activity_code_name': {'key': 'ActivityCodeName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityCodeChild, self).__init__(**kwargs)
        self.activity_code_id = kwargs.get('activity_code_id', None)
        self.activity_code_name = kwargs.get('activity_code_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityCreateRequest(Model):
    """ActivityCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param date_occurred: Required.
    :type date_occurred: datetime
    :param activity_category: Required. Possible values include:
     'SamplingFrequencyChange', 'Description', 'None', 'OperationalCondition',
     'Fault', 'RootCause', 'Evidence', 'Inspection', 'PreventativeMaintenance',
     'CorrectiveMaintenance', 'Observation', 'Document',
     'PendingSamplingFrequencyChange', 'AutoInvalidBurstData',
     'UserInvalidBurstData'
    :type activity_category: str or ~smartdiagnostics_sdk.models.enum
    :param title: Required.
    :type title: str
    :param description:
    :type description: str
    :param activity_document:
    :type activity_document: ~smartdiagnostics_sdk.models.DocumentChild
    :param group_id:
    :type group_id: str
    :param indicator_id:
    :type indicator_id: str
    :param activity_code_ids:
    :type activity_code_ids: list[str]
    :param evidence_indicator_id:
    :type evidence_indicator_id: str
    :param savings:
    :type savings: float
    """

    _validation = {
        'date_occurred': {'required': True},
        'activity_category': {'required': True},
        'title': {'required': True, 'max_length': 50, 'min_length': 0},
        'description': {'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'date_occurred': {'key': 'DateOccurred', 'type': 'iso-8601'},
        'activity_category': {'key': 'ActivityCategory', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'activity_document': {'key': 'ActivityDocument', 'type': 'DocumentChild'},
        'group_id': {'key': 'GroupId', 'type': 'str'},
        'indicator_id': {'key': 'IndicatorId', 'type': 'str'},
        'activity_code_ids': {'key': 'ActivityCodeIds', 'type': '[str]'},
        'evidence_indicator_id': {'key': 'EvidenceIndicatorId', 'type': 'str'},
        'savings': {'key': 'Savings', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(ActivityCreateRequest, self).__init__(**kwargs)
        self.date_occurred = kwargs.get('date_occurred', None)
        self.activity_category = kwargs.get('activity_category', None)
        self.title = kwargs.get('title', None)
        self.description = kwargs.get('description', None)
        self.activity_document = kwargs.get('activity_document', None)
        self.group_id = kwargs.get('group_id', None)
        self.indicator_id = kwargs.get('indicator_id', None)
        self.activity_code_ids = kwargs.get('activity_code_ids', None)
        self.evidence_indicator_id = kwargs.get('evidence_indicator_id', None)
        self.savings = kwargs.get('savings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HeatmapReportRequest(Model):
    """HeatmapReportRequest.

    All required parameters must be populated in order to send to Azure.

    :param aggregate_level: Required. The level at which to aggregate the
     results. Possible values include: 'Indicator', 'MonitoringPoint', 'Asset'
    :type aggregate_level: str or ~smartdiagnostics_sdk.models.enum
    :param hours_per_bin: Required. The size (in hours) to use to split the
     given time range into parts
    :type hours_per_bin: int
    :param filter_id: The filter to use. Optional
    :type filter_id: str
    :param start_date: Required. The start date of the time range to get the
     report for. Nullable so Required can catch nulls, will not
     be null later.
    :type start_date: datetime
    :param end_date: Required. The end date of the time range to get the
     values for. Nullable so Required can catch nulls, will not
     be null later.
    :type end_date: datetime
    :param file_name: Required. The filename to use for the report
    :type file_name: str
    """

    _validation = {
        'aggregate_level': {'required': True},
        'hours_per_bin': {'required': True},
        'start_date': {'required': True},
        'end_date': {'required': True},
        'file_name': {'required': True},
    }

    _attribute_map = {
        'aggregate_level': {'key': 'AggregateLevel', 'type': 'str'},
        'hours_per_bin': {'key': 'HoursPerBin', 'type': 'int'},
        'filter_id': {'key': 'FilterId', 'type': 'str'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'file_name': {'key': 'FileName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(HeatmapReportRequest, self).__init__(**kwargs)
        self.aggregate_level = kwargs.get('aggregate_level', None)
        self.hours_per_bin = kwargs.get('hours_per_bin', None)
        self.filter_id = kwargs.get('filter_id', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.file_name = kwargs.get('file_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RepeaterModelV3(Model):
    """RepeaterModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id:
    :type id: long
    :param serial_number: Required.
    :type serial_number: str
    :param radio_mac_address:
    :type radio_mac_address: str
    :param location_id:
    :type location_id: str
    :param location_name:
    :type location_name: str
    :param corporation_id:
    :type corporation_id: str
    :param corporation_name:
    :type corporation_name: str
    :param last_status_update:
    :type last_status_update: datetime
    :param active:
    :type active: bool
    :param type: Possible values include: 'Unknown', 'BaseStation', 'Repeater'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'serial_number': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'radio_mac_address': {'key': 'RadioMacAddress', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'corporation_name': {'key': 'CorporationName', 'type': 'str'},
        'last_status_update': {'key': 'LastStatusUpdate', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
        'type': {'key': 'Type', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(RepeaterModelV3, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.serial_number = kwargs.get('serial_number', None)
        self.radio_mac_address = kwargs.get('radio_mac_address', None)
        self.location_id = kwargs.get('location_id', None)
        self.location_name = kwargs.get('location_name', None)
        self.corporation_id = kwargs.get('corporation_id', None)
        self.corporation_name = kwargs.get('corporation_name', None)
        self.last_status_update = kwargs.get('last_status_update', None)
        self.active = kwargs.get('active', None)
        self.type = kwargs.get('type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertyRequestChild(Model):
    """PropertyRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param property_name: Required.
    :type property_name: str
    :param property_value_type: Required. Possible values include: 'Boolean',
     'DateTime', 'Double', 'Float', 'Integer', 'String'
    :type property_value_type: str or ~smartdiagnostics_sdk.models.enum
    :param property_required: Required.
    :type property_required: bool
    """

    _validation = {
        'property_name': {'required': True},
        'property_value_type': {'required': True},
        'property_required': {'required': True},
    }

    _attribute_map = {
        'property_name': {'key': 'PropertyName', 'type': 'str'},
        'property_value_type': {'key': 'PropertyValueType', 'type': 'str'},
        'property_required': {'key': 'PropertyRequired', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(PropertyRequestChild, self).__init__(**kwargs)
        self.property_name = kwargs.get('property_name', None)
        self.property_value_type = kwargs.get('property_value_type', None)
        self.property_required = kwargs.get('property_required', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityResponse(Model):
    """ActivityResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param date_occurred: Required.
    :type date_occurred: datetime
    :param description: Required.
    :type description: str
    :param activity_category: Required. Possible values include:
     'SamplingFrequencyChange', 'Description', 'None', 'OperationalCondition',
     'Fault', 'RootCause', 'Evidence', 'Inspection', 'PreventativeMaintenance',
     'CorrectiveMaintenance', 'Observation', 'Document',
     'PendingSamplingFrequencyChange', 'AutoInvalidBurstData',
     'UserInvalidBurstData'
    :type activity_category: str or ~smartdiagnostics_sdk.models.enum
    :param group:
    :type group: ~smartdiagnostics_sdk.models.GroupChild
    :param indicator:
    :type indicator: ~smartdiagnostics_sdk.models.IndicatorChild
    :param activity_codes: Required.
    :type activity_codes: list[~smartdiagnostics_sdk.models.ActivityCodeChild]
    :param activity_document: Required.
    :type activity_document: ~smartdiagnostics_sdk.models.DocumentChild
    :param title: Required.
    :type title: str
    :param evidence_indicator:
    :type evidence_indicator: ~smartdiagnostics_sdk.models.IndicatorChild
    :param created: Required.
    :type created: datetime
    :param created_by: Required.
    :type created_by: str
    :param modified: Required.
    :type modified: datetime
    :param modified_by: Required.
    :type modified_by: str
    :param savings: Required.
    :type savings: float
    :param hierarchy: Required.
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    """

    _validation = {
        'id': {'required': True},
        'location': {'required': True},
        'date_occurred': {'required': True},
        'description': {'required': True},
        'activity_category': {'required': True},
        'activity_codes': {'required': True},
        'activity_document': {'required': True},
        'title': {'required': True},
        'created': {'required': True},
        'created_by': {'required': True},
        'modified': {'required': True},
        'modified_by': {'required': True},
        'savings': {'required': True},
        'hierarchy': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'date_occurred': {'key': 'DateOccurred', 'type': 'iso-8601'},
        'description': {'key': 'Description', 'type': 'str'},
        'activity_category': {'key': 'ActivityCategory', 'type': 'str'},
        'group': {'key': 'Group', 'type': 'GroupChild'},
        'indicator': {'key': 'Indicator', 'type': 'IndicatorChild'},
        'activity_codes': {'key': 'ActivityCodes', 'type': '[ActivityCodeChild]'},
        'activity_document': {'key': 'ActivityDocument', 'type': 'DocumentChild'},
        'title': {'key': 'Title', 'type': 'str'},
        'evidence_indicator': {'key': 'EvidenceIndicator', 'type': 'IndicatorChild'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'created_by': {'key': 'CreatedBy', 'type': 'str'},
        'modified': {'key': 'Modified', 'type': 'iso-8601'},
        'modified_by': {'key': 'ModifiedBy', 'type': 'str'},
        'savings': {'key': 'Savings', 'type': 'float'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
    }

    def __init__(self, *, id: str, location, date_occurred, description: str, activity_category, activity_codes, activity_document, title: str, created, created_by: str, modified, modified_by: str, savings: float, hierarchy, group=None, indicator=None, evidence_indicator=None, **kwargs) -> None:
        super(ActivityResponse, self).__init__(**kwargs)
        self.id = id
        self.location = location
        self.date_occurred = date_occurred
        self.description = description
        self.activity_category = activity_category
        self.group = group
        self.indicator = indicator
        self.activity_codes = activity_codes
        self.activity_document = activity_document
        self.title = title
        self.evidence_indicator = evidence_indicator
        self.created = created
        self.created_by = created_by
        self.modified = modified
        self.modified_by = modified_by
        self.savings = savings
        self.hierarchy = hierarchy



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallAddUserResponse(Model):
    """InstallAddUserResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param install_id:
    :type install_id: str
    :ivar success_count:
    :vartype success_count: int
    :ivar error_count:
    :vartype error_count: int
    """

    _validation = {
        'success_count': {'readonly': True},
        'error_count': {'readonly': True},
    }

    _attribute_map = {
        'install_id': {'key': 'InstallId', 'type': 'str'},
        'success_count': {'key': 'SuccessCount', 'type': 'int'},
        'error_count': {'key': 'ErrorCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(InstallAddUserResponse, self).__init__(**kwargs)
        self.install_id = kwargs.get('install_id', None)
        self.success_count = None
        self.error_count = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineIndicatorChild(Model):
    """BaselineIndicatorChild.

    :param baseline_value:
    :type baseline_value: float
    :param baseline_range_end_date:
    :type baseline_range_end_date: datetime
    :param baseline_range_start_date:
    :type baseline_range_start_date: datetime
    :param baseline_error:
    :type baseline_error: str
    :param baseline_type:
    :type baseline_type: str
    :param baseline_state:
    :type baseline_state: str
    :param baseline_sampling_frequency:
    :type baseline_sampling_frequency: int
    """

    _attribute_map = {
        'baseline_value': {'key': 'BaselineValue', 'type': 'float'},
        'baseline_range_end_date': {'key': 'BaselineRangeEndDate', 'type': 'iso-8601'},
        'baseline_range_start_date': {'key': 'BaselineRangeStartDate', 'type': 'iso-8601'},
        'baseline_error': {'key': 'BaselineError', 'type': 'str'},
        'baseline_type': {'key': 'BaselineType', 'type': 'str'},
        'baseline_state': {'key': 'BaselineState', 'type': 'str'},
        'baseline_sampling_frequency': {'key': 'BaselineSamplingFrequency', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(BaselineIndicatorChild, self).__init__(**kwargs)
        self.baseline_value = kwargs.get('baseline_value', None)
        self.baseline_range_end_date = kwargs.get('baseline_range_end_date', None)
        self.baseline_range_start_date = kwargs.get('baseline_range_start_date', None)
        self.baseline_error = kwargs.get('baseline_error', None)
        self.baseline_type = kwargs.get('baseline_type', None)
        self.baseline_state = kwargs.get('baseline_state', None)
        self.baseline_sampling_frequency = kwargs.get('baseline_sampling_frequency', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupStatusResponse(Model):
    """GroupStatusResponse.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param id: Required.
    :type id: str
    :param alarm_count: Required.
    :type alarm_count: int
    :param warning_count: Required.
    :type warning_count: int
    :param damage_score:
    :type damage_score: float
    :param alarm_severity:
    :type alarm_severity: int
    :param is_snoozed: Required.
    :type is_snoozed: bool
    :param is_paused: Required.
    :type is_paused: bool
    :param analytics_models:
    :type analytics_models:
     list[~smartdiagnostics_sdk.models.AnalyticsModelChild]
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    """

    _validation = {
        'name': {'required': True},
        'id': {'required': True},
        'alarm_count': {'required': True},
        'warning_count': {'required': True},
        'is_snoozed': {'required': True},
        'is_paused': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'id': {'key': 'Id', 'type': 'str'},
        'alarm_count': {'key': 'AlarmCount', 'type': 'int'},
        'warning_count': {'key': 'WarningCount', 'type': 'int'},
        'damage_score': {'key': 'DamageScore', 'type': 'float'},
        'alarm_severity': {'key': 'AlarmSeverity', 'type': 'int'},
        'is_snoozed': {'key': 'IsSnoozed', 'type': 'bool'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'analytics_models': {'key': 'AnalyticsModels', 'type': '[AnalyticsModelChild]'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
    }

    def __init__(self, **kwargs):
        super(GroupStatusResponse, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.id = kwargs.get('id', None)
        self.alarm_count = kwargs.get('alarm_count', None)
        self.warning_count = kwargs.get('warning_count', None)
        self.damage_score = kwargs.get('damage_score', None)
        self.alarm_severity = kwargs.get('alarm_severity', None)
        self.is_snoozed = kwargs.get('is_snoozed', None)
        self.is_paused = kwargs.get('is_paused', None)
        self.analytics_models = kwargs.get('analytics_models', None)
        self.hierarchy = kwargs.get('hierarchy', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemChild(Model):
    """SystemChild.

    All required parameters must be populated in order to send to Azure.

    :param system_id: Required.
    :type system_id: str
    :param system_name: Required.
    :type system_name: str
    :param system_abbreviation:
    :type system_abbreviation: str
    """

    _validation = {
        'system_id': {'required': True},
        'system_name': {'required': True},
    }

    _attribute_map = {
        'system_id': {'key': 'SystemId', 'type': 'str'},
        'system_name': {'key': 'SystemName', 'type': 'str'},
        'system_abbreviation': {'key': 'SystemAbbreviation', 'type': 'str'},
    }

    def __init__(self, *, system_id: str, system_name: str, system_abbreviation: str=None, **kwargs) -> None:
        super(SystemChild, self).__init__(**kwargs)
        self.system_id = system_id
        self.system_name = system_name
        self.system_abbreviation = system_abbreviation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemAssetsStatusSummaryResponse(Model):
    """SystemAssetsStatusSummaryResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param system:
    :type system: ~smartdiagnostics_sdk.models.SystemChild
    :ivar asset_count:
    :vartype asset_count: int
    :param status_count:
    :type status_count: ~smartdiagnostics_sdk.models.AssetsStatusCountChild
    :param status_percentage:
    :type status_percentage:
     ~smartdiagnostics_sdk.models.AssetsStatusPercentageChild
    """

    _validation = {
        'asset_count': {'readonly': True},
    }

    _attribute_map = {
        'system': {'key': 'System', 'type': 'SystemChild'},
        'asset_count': {'key': 'AssetCount', 'type': 'int'},
        'status_count': {'key': 'StatusCount', 'type': 'AssetsStatusCountChild'},
        'status_percentage': {'key': 'StatusPercentage', 'type': 'AssetsStatusPercentageChild'},
    }

    def __init__(self, *, system=None, status_count=None, status_percentage=None, **kwargs) -> None:
        super(SystemAssetsStatusSummaryResponse, self).__init__(**kwargs)
        self.system = system
        self.asset_count = None
        self.status_count = status_count
        self.status_percentage = status_percentage



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetEconomicsChild(Model):
    """AssetEconomicsChild.

    :param asset_cost:
    :type asset_cost: float
    :param date_installed:
    :type date_installed: datetime
    :param annual_run_time:
    :type annual_run_time: float
    :param lost_production_cost:
    :type lost_production_cost: float
    :param overhaul_cost:
    :type overhaul_cost: float
    :param power_consumption:
    :type power_consumption: float
    :param life_expectancy:
    :type life_expectancy: float
    :param unscheduled_downtime:
    :type unscheduled_downtime: float
    """

    _attribute_map = {
        'asset_cost': {'key': 'AssetCost', 'type': 'float'},
        'date_installed': {'key': 'DateInstalled', 'type': 'iso-8601'},
        'annual_run_time': {'key': 'AnnualRunTime', 'type': 'float'},
        'lost_production_cost': {'key': 'LostProductionCost', 'type': 'float'},
        'overhaul_cost': {'key': 'OverhaulCost', 'type': 'float'},
        'power_consumption': {'key': 'PowerConsumption', 'type': 'float'},
        'life_expectancy': {'key': 'LifeExpectancy', 'type': 'float'},
        'unscheduled_downtime': {'key': 'UnscheduledDowntime', 'type': 'float'},
    }

    def __init__(self, *, asset_cost: float=None, date_installed=None, annual_run_time: float=None, lost_production_cost: float=None, overhaul_cost: float=None, power_consumption: float=None, life_expectancy: float=None, unscheduled_downtime: float=None, **kwargs) -> None:
        super(AssetEconomicsChild, self).__init__(**kwargs)
        self.asset_cost = asset_cost
        self.date_installed = date_installed
        self.annual_run_time = annual_run_time
        self.lost_production_cost = lost_production_cost
        self.overhaul_cost = overhaul_cost
        self.power_consumption = power_consumption
        self.life_expectancy = life_expectancy
        self.unscheduled_downtime = unscheduled_downtime



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReleaseRingChild(Model):
    """ReleaseRingChild.

    :param release_ring_id:
    :type release_ring_id: str
    :param release_ring_name:
    :type release_ring_name: str
    """

    _attribute_map = {
        'release_ring_id': {'key': 'ReleaseRingId', 'type': 'str'},
        'release_ring_name': {'key': 'ReleaseRingName', 'type': 'str'},
    }

    def __init__(self, *, release_ring_id: str=None, release_ring_name: str=None, **kwargs) -> None:
        super(ReleaseRingChild, self).__init__(**kwargs)
        self.release_ring_id = release_ring_id
        self.release_ring_name = release_ring_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorFilterUpdateRequest(Model):
    """IndicatorFilterUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param indicator_types:
    :type indicator_types: list[str]
    :param sort_order:
    :type sort_order: int
    :param tag_ids:
    :type tag_ids: list[str]
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'indicator_types': {'key': 'IndicatorTypes', 'type': '[str]'},
        'sort_order': {'key': 'SortOrder', 'type': 'int'},
        'tag_ids': {'key': 'TagIds', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(IndicatorFilterUpdateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.indicator_types = kwargs.get('indicator_types', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.tag_ids = kwargs.get('tag_ids', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelRelatedModelChild(Model):
    """AnalyticsModelRelatedModelChild.

    :param related_model_id:
    :type related_model_id: int
    :param related_model_name:
    :type related_model_name: str
    :param related_model_type: Possible values include: 'SMARTIndicator',
     'Classifier'
    :type related_model_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'related_model_id': {'key': 'RelatedModelId', 'type': 'int'},
        'related_model_name': {'key': 'RelatedModelName', 'type': 'str'},
        'related_model_type': {'key': 'RelatedModelType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelRelatedModelChild, self).__init__(**kwargs)
        self.related_model_id = kwargs.get('related_model_id', None)
        self.related_model_name = kwargs.get('related_model_name', None)
        self.related_model_type = kwargs.get('related_model_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SubSystemResponse(Model):
    """SubSystemResponse.

    All required parameters must be populated in order to send to Azure.

    :param parent:
    :type parent: ~smartdiagnostics_sdk.models.ParentChild
    :param children:
    :type children: list[~smartdiagnostics_sdk.models.DescendantChild]
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param active: Required.
    :type active: bool
    :param is_paused: Required.
    :type is_paused: bool
    :param is_snoozed: Required.
    :type is_snoozed: bool
    :param created: Required.
    :type created: datetime
    :param corporation: Required.
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'active': {'required': True},
        'is_paused': {'required': True},
        'is_snoozed': {'required': True},
        'created': {'required': True},
        'corporation': {'required': True},
        'location': {'required': True},
    }

    _attribute_map = {
        'parent': {'key': 'Parent', 'type': 'ParentChild'},
        'children': {'key': 'Children', 'type': '[DescendantChild]'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'is_snoozed': {'key': 'IsSnoozed', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, **kwargs):
        super(SubSystemResponse, self).__init__(**kwargs)
        self.parent = kwargs.get('parent', None)
        self.children = kwargs.get('children', None)
        self.hierarchy = kwargs.get('hierarchy', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.active = kwargs.get('active', None)
        self.is_paused = kwargs.get('is_paused', None)
        self.is_snoozed = kwargs.get('is_snoozed', None)
        self.created = kwargs.get('created', None)
        self.corporation = kwargs.get('corporation', None)
        self.location = kwargs.get('location', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCriticalityChild(Model):
    """AssetCriticalityChild.

    :param criticality_id:
    :type criticality_id: int
    :param criticality_name:
    :type criticality_name: str
    """

    _attribute_map = {
        'criticality_id': {'key': 'CriticalityId', 'type': 'int'},
        'criticality_name': {'key': 'CriticalityName', 'type': 'str'},
    }

    def __init__(self, *, criticality_id: int=None, criticality_name: str=None, **kwargs) -> None:
        super(AssetCriticalityChild, self).__init__(**kwargs)
        self.criticality_id = criticality_id
        self.criticality_name = criticality_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TriggerChild(Model):
    """TriggerChild.

    All required parameters must be populated in order to send to Azure.

    :param trigger_type: Required. Possible values include: 'Time',
     'NumberOfBurst', 'LinkedSensors'
    :type trigger_type: str or ~smartdiagnostics_sdk.models.enum
    :param trigger_value: Required.
    :type trigger_value: long
    """

    _validation = {
        'trigger_type': {'required': True},
        'trigger_value': {'required': True},
    }

    _attribute_map = {
        'trigger_type': {'key': 'TriggerType', 'type': 'str'},
        'trigger_value': {'key': 'TriggerValue', 'type': 'long'},
    }

    def __init__(self, *, trigger_type, trigger_value: int, **kwargs) -> None:
        super(TriggerChild, self).__init__(**kwargs)
        self.trigger_type = trigger_type
        self.trigger_value = trigger_value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TreeItemChild(Model):
    """TreeItemChild.

    :param tree_item_id:
    :type tree_item_id: str
    :param tree_item_name:
    :type tree_item_name: str
    :param tree_item_abbreviation:
    :type tree_item_abbreviation: str
    """

    _attribute_map = {
        'tree_item_id': {'key': 'TreeItemId', 'type': 'str'},
        'tree_item_name': {'key': 'TreeItemName', 'type': 'str'},
        'tree_item_abbreviation': {'key': 'TreeItemAbbreviation', 'type': 'str'},
    }

    def __init__(self, *, tree_item_id: str=None, tree_item_name: str=None, tree_item_abbreviation: str=None, **kwargs) -> None:
        super(TreeItemChild, self).__init__(**kwargs)
        self.tree_item_id = tree_item_id
        self.tree_item_name = tree_item_name
        self.tree_item_abbreviation = tree_item_abbreviation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CurrentSoftwareReleaseChild(Model):
    """CurrentSoftwareReleaseChild.

    :param current_software_release_id:
    :type current_software_release_id: int
    :param current_software_release_name:
    :type current_software_release_name: str
    """

    _attribute_map = {
        'current_software_release_id': {'key': 'CurrentSoftwareReleaseId', 'type': 'int'},
        'current_software_release_name': {'key': 'CurrentSoftwareReleaseName', 'type': 'str'},
    }

    def __init__(self, *, current_software_release_id: int=None, current_software_release_name: str=None, **kwargs) -> None:
        super(CurrentSoftwareReleaseChild, self).__init__(**kwargs)
        self.current_software_release_id = current_software_release_id
        self.current_software_release_name = current_software_release_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetResponse(Model):
    """AssetResponse.

    All required parameters must be populated in order to send to Azure.

    :param supplier:
    :type supplier: str
    :param manufacturer:
    :type manufacturer: str
    :param model_name:
    :type model_name: str
    :param location_notes:
    :type location_notes: str
    :param notes:
    :type notes: str
    :param generic_input:
    :type generic_input: str
    :param is_operator_view:
    :type is_operator_view: bool
    :param type:
    :type type: ~smartdiagnostics_sdk.models.AssetTypeChild
    :param category:
    :type category: ~smartdiagnostics_sdk.models.AssetCategoryChild
    :param size:
    :type size: ~smartdiagnostics_sdk.models.AssetSizeChild
    :param economics:
    :type economics: ~smartdiagnostics_sdk.models.AssetEconomicsChild
    :param running_speed:
    :type running_speed: ~smartdiagnostics_sdk.models.AssetRunningSpeedChild
    :param criticality:
    :type criticality: ~smartdiagnostics_sdk.models.AssetCriticalityChild
    :param drum_roll:
    :type drum_roll: ~smartdiagnostics_sdk.models.AssetDrumRollChild
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param parent:
    :type parent: ~smartdiagnostics_sdk.models.ParentChild
    :param children:
    :type children: list[~smartdiagnostics_sdk.models.DescendantChild]
    :param tags:
    :type tags: list[~smartdiagnostics_sdk.models.TagChild]
    :param analytics_models:
    :type analytics_models:
     list[~smartdiagnostics_sdk.models.AnalyticsModelChild]
    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param active: Required.
    :type active: bool
    :param is_paused: Required.
    :type is_paused: bool
    :param is_snoozed: Required.
    :type is_snoozed: bool
    :param created: Required.
    :type created: datetime
    :param corporation: Required.
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'active': {'required': True},
        'is_paused': {'required': True},
        'is_snoozed': {'required': True},
        'created': {'required': True},
        'corporation': {'required': True},
        'location': {'required': True},
    }

    _attribute_map = {
        'supplier': {'key': 'Supplier', 'type': 'str'},
        'manufacturer': {'key': 'Manufacturer', 'type': 'str'},
        'model_name': {'key': 'ModelName', 'type': 'str'},
        'location_notes': {'key': 'LocationNotes', 'type': 'str'},
        'notes': {'key': 'Notes', 'type': 'str'},
        'generic_input': {'key': 'GenericInput', 'type': 'str'},
        'is_operator_view': {'key': 'IsOperatorView', 'type': 'bool'},
        'type': {'key': 'Type', 'type': 'AssetTypeChild'},
        'category': {'key': 'Category', 'type': 'AssetCategoryChild'},
        'size': {'key': 'Size', 'type': 'AssetSizeChild'},
        'economics': {'key': 'Economics', 'type': 'AssetEconomicsChild'},
        'running_speed': {'key': 'RunningSpeed', 'type': 'AssetRunningSpeedChild'},
        'criticality': {'key': 'Criticality', 'type': 'AssetCriticalityChild'},
        'drum_roll': {'key': 'DrumRoll', 'type': 'AssetDrumRollChild'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'parent': {'key': 'Parent', 'type': 'ParentChild'},
        'children': {'key': 'Children', 'type': '[DescendantChild]'},
        'tags': {'key': 'Tags', 'type': '[TagChild]'},
        'analytics_models': {'key': 'AnalyticsModels', 'type': '[AnalyticsModelChild]'},
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'is_snoozed': {'key': 'IsSnoozed', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, *, id: str, name: str, active: bool, is_paused: bool, is_snoozed: bool, created, corporation, location, supplier: str=None, manufacturer: str=None, model_name: str=None, location_notes: str=None, notes: str=None, generic_input: str=None, is_operator_view: bool=None, type=None, category=None, size=None, economics=None, running_speed=None, criticality=None, drum_roll=None, hierarchy=None, parent=None, children=None, tags=None, analytics_models=None, abbreviation: str=None, **kwargs) -> None:
        super(AssetResponse, self).__init__(**kwargs)
        self.supplier = supplier
        self.manufacturer = manufacturer
        self.model_name = model_name
        self.location_notes = location_notes
        self.notes = notes
        self.generic_input = generic_input
        self.is_operator_view = is_operator_view
        self.type = type
        self.category = category
        self.size = size
        self.economics = economics
        self.running_speed = running_speed
        self.criticality = criticality
        self.drum_roll = drum_roll
        self.hierarchy = hierarchy
        self.parent = parent
        self.children = children
        self.tags = tags
        self.analytics_models = analytics_models
        self.id = id
        self.name = name
        self.abbreviation = abbreviation
        self.active = active
        self.is_paused = is_paused
        self.is_snoozed = is_snoozed
        self.created = created
        self.corporation = corporation
        self.location = location



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityUpdateRequest(Model):
    """ActivityUpdateRequest.

    :param date_occurred:
    :type date_occurred: datetime
    :param title:
    :type title: str
    :param description:
    :type description: str
    :param activity_document:
    :type activity_document: ~smartdiagnostics_sdk.models.DocumentChild
    :param group_id:
    :type group_id: str
    :param indicator_id:
    :type indicator_id: str
    :param activity_code_ids:
    :type activity_code_ids: list[str]
    :param evidence_indicator_id:
    :type evidence_indicator_id: str
    :param savings:
    :type savings: float
    """

    _validation = {
        'description': {'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'date_occurred': {'key': 'DateOccurred', 'type': 'iso-8601'},
        'title': {'key': 'Title', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'activity_document': {'key': 'ActivityDocument', 'type': 'DocumentChild'},
        'group_id': {'key': 'GroupId', 'type': 'str'},
        'indicator_id': {'key': 'IndicatorId', 'type': 'str'},
        'activity_code_ids': {'key': 'ActivityCodeIds', 'type': '[str]'},
        'evidence_indicator_id': {'key': 'EvidenceIndicatorId', 'type': 'str'},
        'savings': {'key': 'Savings', 'type': 'float'},
    }

    def __init__(self, *, date_occurred=None, title: str=None, description: str=None, activity_document=None, group_id: str=None, indicator_id: str=None, activity_code_ids=None, evidence_indicator_id: str=None, savings: float=None, **kwargs) -> None:
        super(ActivityUpdateRequest, self).__init__(**kwargs)
        self.date_occurred = date_occurred
        self.title = title
        self.description = description
        self.activity_document = activity_document
        self.group_id = group_id
        self.indicator_id = indicator_id
        self.activity_code_ids = activity_code_ids
        self.evidence_indicator_id = evidence_indicator_id
        self.savings = savings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseStationNodeChild(Model):
    """BaseStationNodeChild.

    All required parameters must be populated in order to send to Azure.

    :param base_station_id: Required.
    :type base_station_id: long
    :param base_station_name:
    :type base_station_name: str
    :param base_station_serial_number: Required.
    :type base_station_serial_number: str
    :param base_station_receiver_serial_number: Required.
    :type base_station_receiver_serial_number: str
    """

    _validation = {
        'base_station_id': {'required': True},
        'base_station_serial_number': {'required': True, 'max_length': 8},
        'base_station_receiver_serial_number': {'required': True, 'max_length': 8},
    }

    _attribute_map = {
        'base_station_id': {'key': 'BaseStationId', 'type': 'long'},
        'base_station_name': {'key': 'BaseStationName', 'type': 'str'},
        'base_station_serial_number': {'key': 'BaseStationSerialNumber', 'type': 'str'},
        'base_station_receiver_serial_number': {'key': 'BaseStationReceiverSerialNumber', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BaseStationNodeChild, self).__init__(**kwargs)
        self.base_station_id = kwargs.get('base_station_id', None)
        self.base_station_name = kwargs.get('base_station_name', None)
        self.base_station_serial_number = kwargs.get('base_station_serial_number', None)
        self.base_station_receiver_serial_number = kwargs.get('base_station_receiver_serial_number', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallUpdateRequest(Model):
    """InstallUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param start_date: Required.
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'start_date': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(InstallUpdateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorAlarmStateResponse(Model):
    """IndicatorAlarmStateResponse.

    All required parameters must be populated in order to send to Azure.

    :param current_value: Current Value of indicator
    :type current_value: float
    :param last_update: Last time it was updated
    :type last_update: datetime
    :param id: Required. Id of entity
    :type id: str
    :param alarm_severity: Alarm severity
    :type alarm_severity: int
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'current_value': {'key': 'CurrentValue', 'type': 'float'},
        'last_update': {'key': 'LastUpdate', 'type': 'iso-8601'},
        'id': {'key': 'Id', 'type': 'str'},
        'alarm_severity': {'key': 'AlarmSeverity', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(IndicatorAlarmStateResponse, self).__init__(**kwargs)
        self.current_value = kwargs.get('current_value', None)
        self.last_update = kwargs.get('last_update', None)
        self.id = kwargs.get('id', None)
        self.alarm_severity = kwargs.get('alarm_severity', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingOverview(Model):
    """NodeSettingOverview.

    :param update_interval:
    :type update_interval: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param decimation_factor:
    :type decimation_factor: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param operating_mode_pressure:
    :type operating_mode_pressure:
     ~smartdiagnostics_sdk.models.NodeSettingValues
    :param operating_mode_vibration:
    :type operating_mode_vibration:
     ~smartdiagnostics_sdk.models.NodeSettingValues
    :param number_of_samples:
    :type number_of_samples: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param compression_type:
    :type compression_type: ~smartdiagnostics_sdk.models.NodeSettingValues
    """

    _attribute_map = {
        'update_interval': {'key': 'UpdateInterval', 'type': 'NodeSettingValues'},
        'decimation_factor': {'key': 'DecimationFactor', 'type': 'NodeSettingValues'},
        'operating_mode_pressure': {'key': 'OperatingModePressure', 'type': 'NodeSettingValues'},
        'operating_mode_vibration': {'key': 'OperatingModeVibration', 'type': 'NodeSettingValues'},
        'number_of_samples': {'key': 'NumberOfSamples', 'type': 'NodeSettingValues'},
        'compression_type': {'key': 'CompressionType', 'type': 'NodeSettingValues'},
    }

    def __init__(self, *, update_interval=None, decimation_factor=None, operating_mode_pressure=None, operating_mode_vibration=None, number_of_samples=None, compression_type=None, **kwargs) -> None:
        super(NodeSettingOverview, self).__init__(**kwargs)
        self.update_interval = update_interval
        self.decimation_factor = decimation_factor
        self.operating_mode_pressure = operating_mode_pressure
        self.operating_mode_vibration = operating_mode_vibration
        self.number_of_samples = number_of_samples
        self.compression_type = compression_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserCorporationChild(Model):
    """UserCorporationChild.

    All required parameters must be populated in order to send to Azure.

    :param corporation_id: Required.
    :type corporation_id: str
    :param corporation_name: Required.
    :type corporation_name: str
    :param corporation_abbreviation:
    :type corporation_abbreviation: str
    :param corporation_user_role: Possible values include: 'Invalid',
     'SaasAdmin', 'AccountAdmin', 'ApplicationUser', 'Technician', 'User',
     'SystemProcess', 'Sentry', 'Sales', 'CorporationAdmin', 'CorporationUser',
     'CorporationNone'
    :type corporation_user_role: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'corporation_id': {'required': True},
        'corporation_name': {'required': True},
    }

    _attribute_map = {
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'corporation_name': {'key': 'CorporationName', 'type': 'str'},
        'corporation_abbreviation': {'key': 'CorporationAbbreviation', 'type': 'str'},
        'corporation_user_role': {'key': 'CorporationUserRole', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UserCorporationChild, self).__init__(**kwargs)
        self.corporation_id = kwargs.get('corporation_id', None)
        self.corporation_name = kwargs.get('corporation_name', None)
        self.corporation_abbreviation = kwargs.get('corporation_abbreviation', None)
        self.corporation_user_role = kwargs.get('corporation_user_role', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PowerBiReportChild(Model):
    """PowerBiReportChild.

    :param power_bi_report_access_token:
    :type power_bi_report_access_token: str
    :param power_bi_report_name:
    :type power_bi_report_name: str
    :param power_bi_report_url:
    :type power_bi_report_url: str
    :param power_bi_report_embed_url:
    :type power_bi_report_embed_url: str
    :param error: Possible values include: 'None', 'ReportNotFound', 'Other'
    :type error: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'power_bi_report_access_token': {'key': 'PowerBiReportAccessToken', 'type': 'str'},
        'power_bi_report_name': {'key': 'PowerBiReportName', 'type': 'str'},
        'power_bi_report_url': {'key': 'PowerBiReportUrl', 'type': 'str'},
        'power_bi_report_embed_url': {'key': 'PowerBiReportEmbedUrl', 'type': 'str'},
        'error': {'key': 'Error', 'type': 'str'},
    }

    def __init__(self, *, power_bi_report_access_token: str=None, power_bi_report_name: str=None, power_bi_report_url: str=None, power_bi_report_embed_url: str=None, error=None, **kwargs) -> None:
        super(PowerBiReportChild, self).__init__(**kwargs)
        self.power_bi_report_access_token = power_bi_report_access_token
        self.power_bi_report_name = power_bi_report_name
        self.power_bi_report_url = power_bi_report_url
        self.power_bi_report_embed_url = power_bi_report_embed_url
        self.error = error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MarkerUpdateRequest(Model):
    """MarkerUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param marker_type: Required. Possible values include: 'Fixed',
     'Multiplier'
    :type marker_type: str or ~smartdiagnostics_sdk.models.enum
    :param value: Required.
    :type value: float
    :param order: Required.
    :type order: int
    """

    _validation = {
        'name': {'required': True, 'max_length': 5},
        'marker_type': {'required': True},
        'value': {'required': True, 'minimum': 0},
        'order': {'required': True, 'maximum': 100, 'minimum': 0},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'marker_type': {'key': 'MarkerType', 'type': 'str'},
        'value': {'key': 'Value', 'type': 'float'},
        'order': {'key': 'Order', 'type': 'int'},
    }

    def __init__(self, *, name: str, marker_type, value: float, order: int, **kwargs) -> None:
        super(MarkerUpdateRequest, self).__init__(**kwargs)
        self.name = name
        self.marker_type = marker_type
        self.value = value
        self.order = order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCategoryChild(Model):
    """AssetCategoryChild.

    :param category_id:
    :type category_id: int
    :param category_name:
    :type category_name: str
    :param category_code:
    :type category_code: str
    :param category_marker:
    :type category_marker:
     ~smartdiagnostics_sdk.models.AssetCategoryMarkerChild
    """

    _attribute_map = {
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'category_name': {'key': 'CategoryName', 'type': 'str'},
        'category_code': {'key': 'CategoryCode', 'type': 'str'},
        'category_marker': {'key': 'CategoryMarker', 'type': 'AssetCategoryMarkerChild'},
    }

    def __init__(self, **kwargs):
        super(AssetCategoryChild, self).__init__(**kwargs)
        self.category_id = kwargs.get('category_id', None)
        self.category_name = kwargs.get('category_name', None)
        self.category_code = kwargs.get('category_code', None)
        self.category_marker = kwargs.get('category_marker', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallModifyUsersRequest(Model):
    """InstallModifyUsersRequest.

    :param user_ids:
    :type user_ids: list[str]
    """

    _attribute_map = {
        'user_ids': {'key': 'UserIds', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(InstallModifyUsersRequest, self).__init__(**kwargs)
        self.user_ids = kwargs.get('user_ids', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallResponse(Model):
    """InstallResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param start_date:
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    :ivar active:
    :vartype active: bool
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param users:
    :type users: list[~smartdiagnostics_sdk.models.UserChild]
    :param node_status:
    :type node_status: ~smartdiagnostics_sdk.models.InstallNodesStatusChild
    """

    _validation = {
        'active': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'users': {'key': 'Users', 'type': '[UserChild]'},
        'node_status': {'key': 'NodeStatus', 'type': 'InstallNodesStatusChild'},
    }

    def __init__(self, **kwargs):
        super(InstallResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.active = None
        self.location = kwargs.get('location', None)
        self.corporation = kwargs.get('corporation', None)
        self.users = kwargs.get('users', None)
        self.node_status = kwargs.get('node_status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetTypeChild(Model):
    """AssetTypeChild.

    :param type_id:
    :type type_id: int
    :param type_name:
    :type type_name: str
    :param type_code:
    :type type_code: str
    """

    _attribute_map = {
        'type_id': {'key': 'TypeId', 'type': 'int'},
        'type_name': {'key': 'TypeName', 'type': 'str'},
        'type_code': {'key': 'TypeCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AssetTypeChild, self).__init__(**kwargs)
        self.type_id = kwargs.get('type_id', None)
        self.type_name = kwargs.get('type_name', None)
        self.type_code = kwargs.get('type_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationSettingsChild(Model):
    """LocationSettingsChild.

    :param max_transport_interval:
    :type max_transport_interval: int
    :param max_vibration_update_interval:
    :type max_vibration_update_interval: int
    :param max_oil_quality_update_interval:
    :type max_oil_quality_update_interval: int
    :param opc_enabled:
    :type opc_enabled: bool
    :param assign_filters_to_account:
    :type assign_filters_to_account: bool
    :param external_notification_type: Possible values include: 'Disabled',
     'Automatic', 'Manual'
    :type external_notification_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'max_transport_interval': {'key': 'MaxTransportInterval', 'type': 'int'},
        'max_vibration_update_interval': {'key': 'MaxVibrationUpdateInterval', 'type': 'int'},
        'max_oil_quality_update_interval': {'key': 'MaxOilQualityUpdateInterval', 'type': 'int'},
        'opc_enabled': {'key': 'OpcEnabled', 'type': 'bool'},
        'assign_filters_to_account': {'key': 'AssignFiltersToAccount', 'type': 'bool'},
        'external_notification_type': {'key': 'ExternalNotificationType', 'type': 'str'},
    }

    def __init__(self, *, max_transport_interval: int=None, max_vibration_update_interval: int=None, max_oil_quality_update_interval: int=None, opc_enabled: bool=None, assign_filters_to_account: bool=None, external_notification_type=None, **kwargs) -> None:
        super(LocationSettingsChild, self).__init__(**kwargs)
        self.max_transport_interval = max_transport_interval
        self.max_vibration_update_interval = max_vibration_update_interval
        self.max_oil_quality_update_interval = max_oil_quality_update_interval
        self.opc_enabled = opc_enabled
        self.assign_filters_to_account = assign_filters_to_account
        self.external_notification_type = external_notification_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpectrumChartSettingsCreateRequest(Model):
    """SpectrumChartSettingsCreateRequest.

    :param frequency_domain_settings:
    :type frequency_domain_settings:
     ~smartdiagnostics_sdk.models.FrequencyDomainSettingChild
    :param time_domain_settings:
    :type time_domain_settings: ~smartdiagnostics_sdk.models.MarkerChild
    """

    _attribute_map = {
        'frequency_domain_settings': {'key': 'FrequencyDomainSettings', 'type': 'FrequencyDomainSettingChild'},
        'time_domain_settings': {'key': 'TimeDomainSettings', 'type': 'MarkerChild'},
    }

    def __init__(self, **kwargs):
        super(SpectrumChartSettingsCreateRequest, self).__init__(**kwargs)
        self.frequency_domain_settings = kwargs.get('frequency_domain_settings', None)
        self.time_domain_settings = kwargs.get('time_domain_settings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubPortChild(Model):
    """HubPortChild.

    :param hub_port_id:
    :type hub_port_id: long
    :param hub_port_number:
    :type hub_port_number: int
    :param hub_port_node:
    :type hub_port_node: ~smartdiagnostics_sdk.models.HubNodeChild
    """

    _attribute_map = {
        'hub_port_id': {'key': 'HubPortId', 'type': 'long'},
        'hub_port_number': {'key': 'HubPortNumber', 'type': 'int'},
        'hub_port_node': {'key': 'HubPortNode', 'type': 'HubNodeChild'},
    }

    def __init__(self, **kwargs):
        super(HubPortChild, self).__init__(**kwargs)
        self.hub_port_id = kwargs.get('hub_port_id', None)
        self.hub_port_number = kwargs.get('hub_port_number', None)
        self.hub_port_node = kwargs.get('hub_port_node', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardUpdateRequest(Model):
    """DashboardUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param description:
    :type description: str
    :param time_range: Possible values include: 'EightHours', 'OneDay',
     'OneWeek', 'OneMonth', 'OneYear'
    :type time_range: str or ~smartdiagnostics_sdk.models.enum
    :param dashboard_widgets:
    :type dashboard_widgets:
     list[~smartdiagnostics_sdk.models.DashboardWidgetRequestChild]
    """

    _validation = {
        'name': {'required': True, 'max_length': 128, 'min_length': 0},
        'description': {'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'time_range': {'key': 'TimeRange', 'type': 'str'},
        'dashboard_widgets': {'key': 'DashboardWidgets', 'type': '[DashboardWidgetRequestChild]'},
    }

    def __init__(self, **kwargs):
        super(DashboardUpdateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.time_range = kwargs.get('time_range', None)
        self.dashboard_widgets = kwargs.get('dashboard_widgets', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodeResponse(Model):
    """InstallNodeResponse.

    :param node_id:
    :type node_id: long
    :param install_id:
    :type install_id: str
    :param node_serial_number:
    :type node_serial_number: str
    :param node_nickname:
    :type node_nickname: str
    :param install_status:
    :type install_status: ~smartdiagnostics_sdk.models.InstallNodeStatusChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _attribute_map = {
        'node_id': {'key': 'NodeId', 'type': 'long'},
        'install_id': {'key': 'InstallId', 'type': 'str'},
        'node_serial_number': {'key': 'NodeSerialNumber', 'type': 'str'},
        'node_nickname': {'key': 'NodeNickname', 'type': 'str'},
        'install_status': {'key': 'InstallStatus', 'type': 'InstallNodeStatusChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, **kwargs):
        super(InstallNodeResponse, self).__init__(**kwargs)
        self.node_id = kwargs.get('node_id', None)
        self.install_id = kwargs.get('install_id', None)
        self.node_serial_number = kwargs.get('node_serial_number', None)
        self.node_nickname = kwargs.get('node_nickname', None)
        self.install_status = kwargs.get('install_status', None)
        self.location = kwargs.get('location', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetChild(Model):
    """WidgetChild.

    All required parameters must be populated in order to send to Azure.

    :param widget_id: Required.
    :type widget_id: int
    :param widget_code: Possible values include: 'AssetMonitoring', 'Alerts',
     'TimeWarningAlarm', 'PerformanceOverall', 'PerformanceComparison',
     'PerformanceKpi', 'PerformanceScore', 'PerformanceTrend'
    :type widget_code: str or ~smartdiagnostics_sdk.models.enum
    :param widget_name: Required.
    :type widget_name: str
    :param widget_description:
    :type widget_description: str
    :param widget_type:
    :type widget_type: ~smartdiagnostics_sdk.models.WidgetTypeChild
    """

    _validation = {
        'widget_id': {'required': True},
        'widget_name': {'required': True},
    }

    _attribute_map = {
        'widget_id': {'key': 'WidgetId', 'type': 'int'},
        'widget_code': {'key': 'WidgetCode', 'type': 'str'},
        'widget_name': {'key': 'WidgetName', 'type': 'str'},
        'widget_description': {'key': 'WidgetDescription', 'type': 'str'},
        'widget_type': {'key': 'WidgetType', 'type': 'WidgetTypeChild'},
    }

    def __init__(self, *, widget_id: int, widget_name: str, widget_code=None, widget_description: str=None, widget_type=None, **kwargs) -> None:
        super(WidgetChild, self).__init__(**kwargs)
        self.widget_id = widget_id
        self.widget_code = widget_code
        self.widget_name = widget_name
        self.widget_description = widget_description
        self.widget_type = widget_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StatisticsReportRequest(Model):
    """StatisticsReportRequest.

    All required parameters must be populated in order to send to Azure.

    :param include_percent_time_in_alarm: Whether or not to include percent
     time in alarm in the calculations
    :type include_percent_time_in_alarm: bool
    :param include_percent_time_in_warning: Whether or not to include percent
     time in warning in the calculations
    :type include_percent_time_in_warning: bool
    :param include_percent_on_time: Whether or not to include percent on time
     in the calculations
    :type include_percent_on_time: bool
    :param include_seconds_in_alarm: Whether or not to include time in alarm
     in the calculations
    :type include_seconds_in_alarm: bool
    :param include_average_value: Whether or not to include the average value
     in the calculations
    :type include_average_value: bool
    :param include_max_value: Whether or not to include the max value in the
     calculations
    :type include_max_value: bool
    :param filter_id: The filter to use. Optional
    :type filter_id: str
    :param start_date: Required. The start date of the time range to get the
     report for. Nullable so Required can catch nulls, will not
     be null later.
    :type start_date: datetime
    :param end_date: Required. The end date of the time range to get the
     values for. Nullable so Required can catch nulls, will not
     be null later.
    :type end_date: datetime
    :param file_name: Required. The filename to use for the report
    :type file_name: str
    """

    _validation = {
        'start_date': {'required': True},
        'end_date': {'required': True},
        'file_name': {'required': True},
    }

    _attribute_map = {
        'include_percent_time_in_alarm': {'key': 'IncludePercentTimeInAlarm', 'type': 'bool'},
        'include_percent_time_in_warning': {'key': 'IncludePercentTimeInWarning', 'type': 'bool'},
        'include_percent_on_time': {'key': 'IncludePercentOnTime', 'type': 'bool'},
        'include_seconds_in_alarm': {'key': 'IncludeSecondsInAlarm', 'type': 'bool'},
        'include_average_value': {'key': 'IncludeAverageValue', 'type': 'bool'},
        'include_max_value': {'key': 'IncludeMaxValue', 'type': 'bool'},
        'filter_id': {'key': 'FilterId', 'type': 'str'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'file_name': {'key': 'FileName', 'type': 'str'},
    }

    def __init__(self, *, start_date, end_date, file_name: str, include_percent_time_in_alarm: bool=None, include_percent_time_in_warning: bool=None, include_percent_on_time: bool=None, include_seconds_in_alarm: bool=None, include_average_value: bool=None, include_max_value: bool=None, filter_id: str=None, **kwargs) -> None:
        super(StatisticsReportRequest, self).__init__(**kwargs)
        self.include_percent_time_in_alarm = include_percent_time_in_alarm
        self.include_percent_time_in_warning = include_percent_time_in_warning
        self.include_percent_on_time = include_percent_on_time
        self.include_seconds_in_alarm = include_seconds_in_alarm
        self.include_average_value = include_average_value
        self.include_max_value = include_max_value
        self.filter_id = filter_id
        self.start_date = start_date
        self.end_date = end_date
        self.file_name = file_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TreeItemAvailableAssetClassResponse(Model):
    """TreeItemAvailableAssetClassResponse.

    :param tree_item:
    :type tree_item: ~smartdiagnostics_sdk.models.TreeItemChild
    :param asset_class_code:
    :type asset_class_code: str
    :param asset_type:
    :type asset_type: ~smartdiagnostics_sdk.models.AssetTypeChild
    :param asset_category:
    :type asset_category: ~smartdiagnostics_sdk.models.AssetCategoryChild
    :param asset_size:
    :type asset_size: ~smartdiagnostics_sdk.models.AssetSizeChild
    """

    _attribute_map = {
        'tree_item': {'key': 'TreeItem', 'type': 'TreeItemChild'},
        'asset_class_code': {'key': 'AssetClassCode', 'type': 'str'},
        'asset_type': {'key': 'AssetType', 'type': 'AssetTypeChild'},
        'asset_category': {'key': 'AssetCategory', 'type': 'AssetCategoryChild'},
        'asset_size': {'key': 'AssetSize', 'type': 'AssetSizeChild'},
    }

    def __init__(self, *, tree_item=None, asset_class_code: str=None, asset_type=None, asset_category=None, asset_size=None, **kwargs) -> None:
        super(TreeItemAvailableAssetClassResponse, self).__init__(**kwargs)
        self.tree_item = tree_item
        self.asset_class_code = asset_class_code
        self.asset_type = asset_type
        self.asset_category = asset_category
        self.asset_size = asset_size



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCreateRequest(Model):
    """AssetCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param parent_id: Required.
    :type parent_id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param supplier:
    :type supplier: str
    :param manufacturer:
    :type manufacturer: str
    :param model_name:
    :type model_name: str
    :param location_notes:
    :type location_notes: str
    :param notes:
    :type notes: str
    :param generic_input:
    :type generic_input: str
    :param is_operator_view: Required.
    :type is_operator_view: bool
    :param type_id:
    :type type_id: int
    :param category_id:
    :type category_id: int
    :param size_id:
    :type size_id: int
    :param criticality_id:
    :type criticality_id: int
    :param asset_cost:
    :type asset_cost: float
    :param date_installed:
    :type date_installed: datetime
    :param annual_run_time:
    :type annual_run_time: float
    :param lost_production_cost:
    :type lost_production_cost: float
    :param overhaul_cost:
    :type overhaul_cost: float
    :param power_consumption:
    :type power_consumption: float
    :param life_expectancy:
    :type life_expectancy: float
    :param unscheduled_downtime:
    :type unscheduled_downtime: float
    :param running_speed_harmonic:
    :type running_speed_harmonic: float
    """

    _validation = {
        'parent_id': {'required': True},
        'name': {'required': True, 'max_length': 100},
        'abbreviation': {'max_length': 5},
        'supplier': {'max_length': 128},
        'manufacturer': {'max_length': 128},
        'model_name': {'max_length': 128},
        'location_notes': {'max_length': 256},
        'notes': {'max_length': 2000},
        'generic_input': {'max_length': 2000},
        'is_operator_view': {'required': True},
    }

    _attribute_map = {
        'parent_id': {'key': 'ParentId', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'supplier': {'key': 'Supplier', 'type': 'str'},
        'manufacturer': {'key': 'Manufacturer', 'type': 'str'},
        'model_name': {'key': 'ModelName', 'type': 'str'},
        'location_notes': {'key': 'LocationNotes', 'type': 'str'},
        'notes': {'key': 'Notes', 'type': 'str'},
        'generic_input': {'key': 'GenericInput', 'type': 'str'},
        'is_operator_view': {'key': 'IsOperatorView', 'type': 'bool'},
        'type_id': {'key': 'TypeId', 'type': 'int'},
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'size_id': {'key': 'SizeId', 'type': 'int'},
        'criticality_id': {'key': 'CriticalityId', 'type': 'int'},
        'asset_cost': {'key': 'AssetCost', 'type': 'float'},
        'date_installed': {'key': 'DateInstalled', 'type': 'iso-8601'},
        'annual_run_time': {'key': 'AnnualRunTime', 'type': 'float'},
        'lost_production_cost': {'key': 'LostProductionCost', 'type': 'float'},
        'overhaul_cost': {'key': 'OverhaulCost', 'type': 'float'},
        'power_consumption': {'key': 'PowerConsumption', 'type': 'float'},
        'life_expectancy': {'key': 'LifeExpectancy', 'type': 'float'},
        'unscheduled_downtime': {'key': 'UnscheduledDowntime', 'type': 'float'},
        'running_speed_harmonic': {'key': 'RunningSpeedHarmonic', 'type': 'float'},
    }

    def __init__(self, *, parent_id: str, name: str, is_operator_view: bool, abbreviation: str=None, supplier: str=None, manufacturer: str=None, model_name: str=None, location_notes: str=None, notes: str=None, generic_input: str=None, type_id: int=None, category_id: int=None, size_id: int=None, criticality_id: int=None, asset_cost: float=None, date_installed=None, annual_run_time: float=None, lost_production_cost: float=None, overhaul_cost: float=None, power_consumption: float=None, life_expectancy: float=None, unscheduled_downtime: float=None, running_speed_harmonic: float=None, **kwargs) -> None:
        super(AssetCreateRequest, self).__init__(**kwargs)
        self.parent_id = parent_id
        self.name = name
        self.abbreviation = abbreviation
        self.supplier = supplier
        self.manufacturer = manufacturer
        self.model_name = model_name
        self.location_notes = location_notes
        self.notes = notes
        self.generic_input = generic_input
        self.is_operator_view = is_operator_view
        self.type_id = type_id
        self.category_id = category_id
        self.size_id = size_id
        self.criticality_id = criticality_id
        self.asset_cost = asset_cost
        self.date_installed = date_installed
        self.annual_run_time = annual_run_time
        self.lost_production_cost = lost_production_cost
        self.overhaul_cost = overhaul_cost
        self.power_consumption = power_consumption
        self.life_expectancy = life_expectancy
        self.unscheduled_downtime = unscheduled_downtime
        self.running_speed_harmonic = running_speed_harmonic



import setuptools

with open("version.txt", "r") as version_file:
    version = version_file.read().strip()

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="smartdiagnostics-sdk", # Replace with your own username
    version=version,
    author="KCF Technologies, Inc",
    author_email="python-packages@kcftech.com",
    description="Python SDK for executing the SMARTdiagnostics API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://www.kcftech.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareStatusResponse(Model):
    """HardwareStatusResponse.

    :param location_hardware_statuses:
    :type location_hardware_statuses:
     list[~smartdiagnostics_sdk.models.HardwareStatusChild]
    :param total_hardware_count:
    :type total_hardware_count: int
    :param total_unassigned_count:
    :type total_unassigned_count: int
    :param total_online_count:
    :type total_online_count: int
    :param total_offline_count:
    :type total_offline_count: int
    """

    _attribute_map = {
        'location_hardware_statuses': {'key': 'LocationHardwareStatuses', 'type': '[HardwareStatusChild]'},
        'total_hardware_count': {'key': 'TotalHardwareCount', 'type': 'int'},
        'total_unassigned_count': {'key': 'TotalUnassignedCount', 'type': 'int'},
        'total_online_count': {'key': 'TotalOnlineCount', 'type': 'int'},
        'total_offline_count': {'key': 'TotalOfflineCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(HardwareStatusResponse, self).__init__(**kwargs)
        self.location_hardware_statuses = kwargs.get('location_hardware_statuses', None)
        self.total_hardware_count = kwargs.get('total_hardware_count', None)
        self.total_unassigned_count = kwargs.get('total_unassigned_count', None)
        self.total_online_count = kwargs.get('total_online_count', None)
        self.total_offline_count = kwargs.get('total_offline_count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeStatusChild(Model):
    """NodeStatusChild.

    :param outstanding:
    :type outstanding: int
    :param deployed:
    :type deployed: int
    :param lock_out_tag_out:
    :type lock_out_tag_out: int
    :param spare_devices:
    :type spare_devices: int
    :param special_access_required:
    :type special_access_required: int
    """

    _attribute_map = {
        'outstanding': {'key': 'Outstanding', 'type': 'int'},
        'deployed': {'key': 'Deployed', 'type': 'int'},
        'lock_out_tag_out': {'key': 'LockOutTagOut', 'type': 'int'},
        'spare_devices': {'key': 'SpareDevices', 'type': 'int'},
        'special_access_required': {'key': 'SpecialAccessRequired', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(NodeStatusChild, self).__init__(**kwargs)
        self.outstanding = kwargs.get('outstanding', None)
        self.deployed = kwargs.get('deployed', None)
        self.lock_out_tag_out = kwargs.get('lock_out_tag_out', None)
        self.spare_devices = kwargs.get('spare_devices', None)
        self.special_access_required = kwargs.get('special_access_required', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FrequencyDomainSettingChild(Model):
    """FrequencyDomainSettingChild.

    :param markers:
    :type markers: list[~smartdiagnostics_sdk.models.MarkerChild]
    :param custom_markers:
    :type custom_markers: list[~smartdiagnostics_sdk.models.CustomMarkerChild]
    :param selected_bearing:
    :type selected_bearing: str
    :param side_bands:
    :type side_bands: int
    :param side_band_frequency:
    :type side_band_frequency: int
    """

    _attribute_map = {
        'markers': {'key': 'Markers', 'type': '[MarkerChild]'},
        'custom_markers': {'key': 'CustomMarkers', 'type': '[CustomMarkerChild]'},
        'selected_bearing': {'key': 'SelectedBearing', 'type': 'str'},
        'side_bands': {'key': 'SideBands', 'type': 'int'},
        'side_band_frequency': {'key': 'SideBandFrequency', 'type': 'int'},
    }

    def __init__(self, *, markers=None, custom_markers=None, selected_bearing: str=None, side_bands: int=None, side_band_frequency: int=None, **kwargs) -> None:
        super(FrequencyDomainSettingChild, self).__init__(**kwargs)
        self.markers = markers
        self.custom_markers = custom_markers
        self.selected_bearing = selected_bearing
        self.side_bands = side_bands
        self.side_band_frequency = side_band_frequency



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BearingResponse(Model):
    """BearingResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name:
    :type name: str
    :param manufacturer:
    :type manufacturer: str
    :param roller_count:
    :type roller_count: long
    :param ftf:
    :type ftf: float
    :param bsf:
    :type bsf: float
    :param bpfo:
    :type bpfo: float
    :param bpfi:
    :type bpfi: float
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'manufacturer': {'key': 'Manufacturer', 'type': 'str'},
        'roller_count': {'key': 'RollerCount', 'type': 'long'},
        'ftf': {'key': 'Ftf', 'type': 'float'},
        'bsf': {'key': 'Bsf', 'type': 'float'},
        'bpfo': {'key': 'Bpfo', 'type': 'float'},
        'bpfi': {'key': 'Bpfi', 'type': 'float'},
    }

    def __init__(self, *, id: str, name: str=None, manufacturer: str=None, roller_count: int=None, ftf: float=None, bsf: float=None, bpfo: float=None, bpfi: float=None, **kwargs) -> None:
        super(BearingResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.manufacturer = manufacturer
        self.roller_count = roller_count
        self.ftf = ftf
        self.bsf = bsf
        self.bpfo = bpfo
        self.bpfi = bpfi
